*** This file explores the data

* create file with basic information

use data\weights.dta, clear
keep hhid stratum weight
sort hhid
save temp, replace
 
use data\metadata_cl.dta, clear
rename m0_ur urbrur
rename m0_q08d day
rename m0_q08m month
rename m0_q02 comune
*rename m0_q11 latitude
*rename m0_q12 longitude
encode m0_q1b, gen(district1) label(district)
label def district 9 "GRAMSH", modify
label def district 10 "GJIROKASTER", modify
label def district 31 "SKRAPAR", modify
label def district 32 "SHKODER", modify
label def district 16 "KU?OVE", modify
label def district 17 "KUKES", modify
label def district 18 "KURBIN", modify
gen district=m0_q1a
label val district district
keep psu hhid urbrur day month district comune 
sort hhid
merge hhid using temp
tab _merge
drop _merge
sort hhid
save results\base, replace

tab urbrur
collapse urbrur, by(hhid)
tab urbrur

* ok

* add prefectures

use results\prefect, clear
sort prefecture
encode name, gen(name1) label(name)
keep district name1
rename name1 prefect
sort district
save temp, replace

use results\base
sort district
merge district using temp
tab _merge
drop _merge
gen area=1 if psu>=376
replace area=2 if urbrur==1 & area==.
replace area=3 if urbrur==2
label def area1 1 "Tirana"
label def area1 2 "Other urban", add
label def area1 3 "Rural", add
label val area area1
sort hhid
save results\base, replace

* check household size

use data\hhroster_cl.dta, clear
tab m1_q03 if m1_q12==2
tab m1_q05m if m1_q12==2

gen member=1 if m1_q11<7 | m1_q03==1 | (m1_q05y==0 & m1_q05m<7)
recode member .=0

tab member m1_q12
tab m1_q03 if member==1 & m1_q12==2
tab m1_q05y m1_q05m if member==1 & m1_q12==2

save temp, replace

gen thhsize=1
collapse (sum) thhsize hhsize=member, by(hhid)
sum thhsize hhsize

use temp, clear
drop if member==0
drop member
sort hhid
save results\hhroster, replace


**********************************************
**** The following syntax can be ignored  ****
**********************************************


* general overview of level of expenses

clear
set mem 10m

* Non food expenses

use data\nonfoodexp_1m_cl.dta, clear
des
table mba_q00, c(m mba_q03 n mba_q03 min mba_q03 max mba_q03)

use data\nonfoodexp_6m_cl.dta, clear
des
table mbb_q00, c(m mbb_q03 n mbb_q03 min mbb_q03 max mbb_q03)

use data\nonfoodexp_12m_cl.dta, clear
des
table mbc_q00, c(m mbc_q03 n mbc_q03 min mbc_q03 max mbc_q03)

* Food expenses

use data\bookdaily_cl.dta, clear
des
encode maa_q03, gen(itc)
sort maa_q07
by maa_q07: table itc, c(m maa_q06 n maa_q06 min maa_q06 max maa_q06)

use data\bfoodeaten_cl.dta, clear
des
encode mac_q03, gen(itc)
table itc, c(m mac_q04 n mac_q04 min mac_q04 max mac_q04)

use data\bnonpurchased_cl.dta, clear
des
encode mab_q03, gen(itc)
table itc, c(m mab_q06 n mab_q06 min mab_q06 max mab_q06)


* make sure that there are not duplicates 

use data\hhroster_cl.dta, clear
drop m1_q01
egen test=rsum(m1_q00-m1_q12)
collapse (sum) test, by(hhid)
sort hhid
save temp, replace

use data\hhroster_cl.dta, clear
egen test1=rsum(m2_q01-m2_q03)
collapse (sum) test1, by(hhid)
sort hhid
merge hhid using temp
tab _merge
drop _merge
sort hhid
save temp, replace

use data\labor_c_cl.dta, clear
egen test2=rsum(m7c_q2a-m7c_q09)
collapse (sum) test2, by(hhid)
sort hhid
merge hhid using temp
tab _merge
drop _merge
recode test2 .=0
sort hhid
save temp, replace

use data\dwelling_cl, clear
drop m3a_q5b
egen test3=rsum(m3a_q01-m3a_q09)
egen test4=rsum(m3a_q10-m3a_q11_7)
collapse (sum) test3 test4, by(hhid)
sort hhid
merge hhid using temp
tab _merge
drop _merge
summ
summ test test1 test2 test3 test4, d

* we try to create a unique identifier
replace test3=test3*10 if test3<100
sum test3
replace test1=test1*10 if test1<10
sum test1

gen double code=test*10000000 if test<10000
replace code=test*1000000 if test>=10000
replace code=code+test3*1000
replace code=code+test1*10
replace code=code+test4
sort code
gen ncases=1
collapse (min) hhid (sum) ncases, by(code)
keep if ncases>=2
drop ncases
sort code
save temp1, replace

use data\dwelling_cl, clear
drop m3a_q5b
egen test3=rsum(m3a_q01-m3a_q09)
egen test4=rsum(m3a_q10-m3a_q11_7)
collapse (sum) test3 test4, by(hhid)
sort hhid
merge hhid using temp
tab _merge
drop _merge
replace test3=test3*10 if test3<100
replace test1=test1*10 if test1<10
gen double code=test*10000000 if test<10000
replace code=test*1000000 if test>=10000
replace code=code+test3*1000
replace code=code+test1*10
replace code=code+test4
sort code
gen ncases=1
collapse (max) hhid (sum) ncases, by(code)
keep if ncases>=2
rename hhid hhid1
sort code
merge code using temp1
tab _merge
drop _merge
sort hhid

* after making few checks we can say that there are no obvious duplicates





 






