* this file calculates the PSU paasche price index with community and household prices

clear
set mem 40m

use results\hhroster, clear
gen hhsize=1
collapse (sum) hhsize, by(hhid)
sort hhid
save temp, replace
use "results\base", clear
sort hhid
merge hhid using temp
tab _merge
drop _merge
sort hhid
merge hhid using results\prices1
tab _merge
drop _merge
collapse (mean) stratum prefect urbrur area psu weight hhsize, by(hhid)
gen pweight=weight*hhsize
egen totpop=sum(pweight)
egen pop_pr=sum(pweight), by(stratum urbrur)
egen pop_psu=sum(pweight), by(psu)
sort hhid
merge hhid using results\prices1
tab _merge
drop _merge
* we can calculate the index with and without including the non food items
*drop if itc>=300
save tempor, replace

** 1.

* calculate budget shares (average by population)
use tempor, clear
rename exp consi
label var consi "Consumption per item"
egen double const=sum(consi), by(hhid)
label var const "Total Consumption per household"
gen double wi=consi/const
replace wi=wi*pweight
collapse (sum) wi (mean) pop_psu, by(psu itc)
gen wipsu=wi/pop_psu
label var wipsu "Budget share of item by psu"
summ
* just to check
egen totsh=sum(wipsu), by(psu)
summ totsh
compress
drop totsh wi
sort psu itc
save temp1, replace

** 2.

* calculate median prices by psu with implicit household prices and community questionnaire prices
use tempor, clear
* for four items we only have information on prices in the community price questionnaire
replace psuprice1=comprice1 if psuprice1==.
collapse (mean) psuprice1 comprice1, by(psu itc)
label var psuprice1 "household implicit price per psu"
label var comprice1 "community price per psu"
summ
compress
sort psu itc
save temp2, replace

** 3.

* to calculate the price of each food item at a national level using weights
use tempor, clear
replace psuprice1=comprice1 if psuprice1==.
collapse (mean) h_p0=psuprice1 c_p0=comprice1 [pweight=weight], by(itc)
label var h_p0 "household price (national level)"
label var c_p0 "community price (national level)"
summ
compress
sort itc
save temp3, replace

clear
set mem 10m

** 4.

use results\base, clear
keep hhid area stratum urbrur prefect psu weight
sort psu
save temp4, replace

use temp1, clear
merge psu itc using temp2
tab _merge
drop _merge
sort itc
merge itc using temp3
tab _merge
drop _merge
gen double h_lnindex= wipsu*log(psuprice1/h_p0)
gen double c_lnindex= wipsu*log(comprice1/c_p0)
collapse (sum) h_lnindex c_lnindex, by(psu)
gen h_psupind=exp(h_lnindex)
gen c_psupind=exp(c_lnindex)
label var h_psupind "Household Paasche Index by psu"
label var c_psupind "Coomunity Paasche Index by psu"
drop h_lnindex c_lnindex
summ
merge psu using temp4
tab _merge
drop _merge
sort hhid
summ h_psupind [weight=weight]
gen hnorm=_result(3)
summ c_psupind [weight=weight]
gen cnorm=_result(3)
replace h_psupind=h_psupind/hnorm
label var h_psupind "Household Paasche Index (normalized)"
replace c_psupind=c_psupind/cnorm
label var c_psupind "Community Paasche Index (normalized)"
drop hnorm cnorm
compress
sort hhid
save results\psupind1.dta, replace
* to obtain the average Paasche Index by region (urban/rural) and province
table stratum urbrur [pw=weight], c(m h_psupind) row col
table stratum urbrur [pw=weight], c(m c_psupind) row col

table area [pw=weight], c(m h_psupind) row col
table area [pw=weight], c(m c_psupind) row col


! del temp*.dta


*** Differences in the indexes are small, but the inclusion of non food items is sensitive to the price of reference of groups of non food items as reported
*** in the budget share




