*** This file generates some sensitivity analysis on households size and economies of scale

clear
set mem 30m

use results\hhroster, clear
count if m1_q05y==.
rename m1_q05y age
gen child=1 if age<=15
gen adult=1 if age>=16 & age<=59 & m1_q02==1
replace adult=1 if age>=16 & age<=54 & m1_q02==2
gen elder=1 if age>=60 & m1_q02==1
replace elder=1 if age>=55 & m1_q02==2
gen femhead=1 if m1_q03==1 & m1_q02==2
gen hhsize=1
collapse (sum) hhsize child adult elder femhead, by(hhid)
egen test=rsum(child adult elder)
count if test!=hhsize
drop test
sort hhid
merge hhid using results\base
tab _merge
drop if _merge==2
drop _merge
gen pweight=weight*hhsize
gen depratio=(child+elder)/hhsize
gen childprop=child/hhsize
sum depratio [aw=weight]
gen highdep=1 if depratio>r(mean)
sum depratio [aw=weight]
gen highchild=1 if childprop>r(mean)
gen eldhh=1 if elder==hhsize
gen hhnochild=1 if child==0
gen hh1child=1 if child==1
gen hh2child=1 if child==2
gen hh3mchild=1 if child>=3
for var femhead highdep-hh3mchild: recode X .=0 1=100

* We have the following groups

table area [pw=pweight], c(m eldhh m femhead m highdep m highchild) row
table area [pw=pweight], c(m hhnochild m hh1child m hh2child m hh3mchild) row

sort hhid
merge hhid using results\poverty
tab _merge
drop _merge

sort hhid
save temp, replace

* various hypotheses on teta

local i = 1
while `i' <= 10 {
use temp, clear
gen rcons`i'=(totcons3/psupind)/(hhsize^(`i'/10))
cumul rcons`i' [aw=pweight], gen(cdf)
gen poor=100 if cdf<=0.254
recode poor .=0
gen eldpoor=poor if eldhh==100
gen fhpoor=poor if femhead==100
gen hdpoor=poor if highdep==100
gen hcpoor=poor if highchild==100
gen hnocpoor=poor if hhnochild==100
gen h1cpoor=poor if hh1child==100
gen h2cpoor=poor if hh2child==100
gen h3mcpoor=poor if hh3mchild==100
gen phhsize=hhsize if poor==100
gen nphhsize=hhsize if poor==0
gen poorchild=child if poor==100
gen pooreld=elder if poor==100
gen teta=`i'/10
save temp33, replace
collapse (mean) poor-h3mcpoor [pw=pweight], by(teta)
sort teta
save temp331, replace
use temp33, clear
collapse (mean) phhsize nphhsize (sum) child poorchild elder pooreld [pw=weight], by(teta)
gen ppchild=(poorchild/child)*100
gen ppeld=(pooreld/elder)*100
drop child poorchild elder pooreld
sort teta
save temp332, replace
use temp331, clear
sort teta
merge teta using temp332
drop _merge
sort teta
save temp`i', replace
local i = `i' + 1
}

use temp1, clear
sort teta
merge teta using temp2
drop _merge
sort teta
merge teta using temp3
drop _merge
sort teta
merge teta using temp4
drop _merge
sort teta
merge teta using temp5
drop _merge
sort teta
merge teta using temp6
drop _merge
sort teta
merge teta using temp7
drop _merge
sort teta
merge teta using temp8
drop _merge
sort teta
merge teta using temp9
drop _merge
sort teta
merge teta using temp10
drop _merge
sort teta
save results\econscale, replace

list



*** OECD equivalence scales, ECA parameter, 

use temp, clear
drop hhsize1
gen hhsize1=1+0.5*(hhsize-child-1)+child*0.3
label var hhsize1 "new OECD scale"
gen hhsize2=1+0.7*(hhsize-child-1)+child*0.5
label var hhsize2 "old OECD scale"
gen hhsize3=(hhsize)^0.75
label var hhsize3 "0.75 ECA parameter"
gen hhsize4=hhsize
label var hhsize4 "per capita"
save temp, replace

* various hypotheses on teta

local i = 1
while `i' <= 4 {
use temp, clear
gen rcons`i'=(totcons3/psupind)/(hhsize`i')
cumul rcons`i' [aw=pweight], gen(cdf)
gen poor=100 if cdf<=0.254
recode poor .=0
gen eldpoor=poor if eldhh==100
gen fhpoor=poor if femhead==100
gen hdpoor=poor if highdep==100
gen hcpoor=poor if highchild==100
gen hnocpoor=poor if hhnochild==100
gen h1cpoor=poor if hh1child==100
gen h2cpoor=poor if hh2child==100
gen h3mcpoor=poor if hh3mchild==100
gen phhsize=hhsize if poor==100
gen nphhsize=hhsize if poor==0
gen poorchild=child if poor==100
gen pooreld=elder if poor==100
gen teta=`i'
save temp33, replace
collapse (mean) poor-h3mcpoor [pw=pweight], by(teta)
sort teta
save temp331, replace
use temp33, clear
collapse (mean) phhsize nphhsize (sum) child poorchild elder pooreld [pw=weight], by(teta)
gen ppchild=(poorchild/child)*100
gen ppeld=(pooreld/elder)*100
drop child poorchild elder pooreld
sort teta
save temp332, replace
use temp331, clear
sort teta
merge teta using temp332
drop _merge
sort teta
save temp`i', replace
local i = `i' + 1
}

use temp1, clear
sort teta
merge teta using temp2
drop _merge
sort teta
merge teta using temp3
drop _merge
sort teta
merge teta using temp4
drop _merge
sort teta

lab def teta 1 "new OECD scale" 
lab def teta 2 "old OECD scale", add
lab def teta 3 "0.75 ECA parameter", add
lab def teta 4 "per capita", add
lab val teta teta

list

save results\econscale1, replace



use temp, clear
drop rpcons rpcons1 rpcons3 hhsize1 hhsize2 hhsize3 hhsize4
gen rpcons=(totcons3/hhsize)/psupind


* we want to compare adult vs elder, adult vs child, adult vs child5, and adult vs child6_15

***************************************
********** Adult vs elderly ***********
***************************************

tab adult elder if child==0

* we compare the following families: 2 adults and 2 adults and 1 elder

cumul rpcons [aweight=pweight] if adult==2 & elder==0 & child==0, gen(adult2)
cumul rpcons [aweight=pweight] if adult==2 & elder==1 & child==0, gen(ad2eld1)
#delimit ;
graph adult2 ad2eld1 rpcons if rpcons<15000, c(ll) s(..) sort
  xlabel(2500, 5000, 7500, 10000, 12500, 15000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr

* The extreme hypothesis is that elderly people need 0.7 and adult

gen eqelder=elder*0.7
egen hhsize1=rsum(adult eqelder child)

gen rpcons1=totcons3/(psupind*hhsize1)

cumul rpcons1 [aweight=pweight] if adult==2 & elder==1 & child==0, gen(ad2eld11)
#delimit ;
graph adult2 ad2eld11 rpcons1 if rpcons1<15000, c(ll) s(..) sort
  xlabel(2500, 5000, 7500, 10000, 12500, 15000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr

*** Even if this hypothesis is verified larger households are worse off



***************************************
**********  Adult vs child  ***********
***************************************

tab adult child if elder==0

cumul rpcons [aweight=pweight] if adult==2 & elder==0 & child==1, gen(ad2ch1)
cumul rpcons [aweight=pweight] if adult==2 & elder==0 & child==2, gen(ad2ch2)
cumul rpcons [aweight=pweight] if adult==2 & elder==0 & child==3, gen(ad2ch3)
cumul rpcons [aweight=pweight] if adult==2 & elder==0 & child==4, gen(ad2ch4)

#delimit ;
graph adult2 ad2ch1 ad2ch2 ad2ch3 ad2ch4 rpcons if rpcons<10000, c(lllll) s(.....) sort
  xlabel(2500, 5000, 7500, 10000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr

* here the extreme hypothesis could be that people less than 16 need only 0.5 an adult

gen eqch=child*0.5
egen hhsize2=rsum(adult elder eqch)

gen rpcons2=totcons3/(psupind*hhsize2)

cumul rpcons2 [aweight=pweight] if adult==2 & elder==0 & child==1, gen(ad2ch11)
cumul rpcons2 [aweight=pweight] if adult==2 & elder==0 & child==2, gen(ad2ch21)
cumul rpcons2 [aweight=pweight] if adult==2 & elder==0 & child==3, gen(ad2ch31)
cumul rpcons2 [aweight=pweight] if adult==2 & elder==0 & child==4, gen(ad2ch41)

#delimit ;
graph adult2 ad2ch11 ad2ch21 ad2ch31 ad2ch41 rpcons2 if rpcons2<10000, c(lllll) s(.....) sort
  xlabel(2500, 5000, 7500, 10000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr


*** Even if this hypothesis is verified larger households are worse off




