*** This file computes education and health expenses

clear
set mem 20m

**************************************
*****                            *****
*****         EDUCATION          *****
*****                            *****
**************************************

* the monthly minimum wage is 7580 leks, assuming 22 days working days per month and 8 hours of work per day, a hour of work is worth about 43 leks.
* This is used to impute the value of hours of service given as form of payment to schools

use results\hhroster, clear

* Pre-school
gen typep=m4a_q03
label val typep M4A_Q03
egen typep_mx=max(typep), by(hhid)
egen typep_mn=min(typep), by(hhid)
gen pservice=43*m4a_q09
tab m4a_q05
* very high values that should be checked
tab hhid if m4a_q05>=5000 & m4a_q05!=.
tab m4a_q07
tab pservice
egen preschool=rsum(m4a_q05 m4a_q07 pservice)
rename m4a_q05 pfee
rename m4a_q07 pgift
replace preschool=preschool*9/12
gen npresch=1 if m4a_q01==1
table typep, c(m preschool med preschool n preschool max preschool)

* School
gen type=m4b_q15
label val type M4B_Q15
egen type_mx=max(type), by(hhid)
egen type_mn=min(type), by(hhid)
gen transport=m4b_q22
tab transport
for var m4b_q23-m4b_q28: recode X 99997=. 999997=.
egen total=rsum(m4b_q23-m4b_q28)
rename m4b_q23 fee
rename m4b_q24 uniform
rename m4b_q25 textbook
rename m4b_q26 material
rename m4b_q27 lodging
rename m4b_q28 other
gen total1=m4b_q29
recode total 0=.
recode total1 0=.
sum total total1
tab total1 if total==.
count if total1!=. & total==.
count if total1==. & total!=.
count if total1>total & total!=.
count if total1<total & total!=.
list total1 total fee-other if total1<total & total!=.
replace total1=total if total1<total & total!=.
count if total1==. & transport!=.
gen tutor=m4b_q35
gen gift=m4b_q37
gen service=m4b_q39*43
replace transport=transport*9
replace tutor=tutor*9
egen eduexp=rsum(total1 transport tutor gift service)
replace eduexp=eduexp/12
gen level=m4b_q13
lab val level M4B_Q13
gen grade=m4b_q14
lab val grade M4B_Q14
tab level type if eduexp>=5000
recode eduexp 0=. if level==.
tab level if eduexp==0
table level, c(m eduexp med eduexp n eduexp)
table type, c(m eduexp med eduexp n eduexp)
gen nsch=1 if m4b_q09==1
keep npresch preschool pfee pgift pservice nsch transport fee uniform textbook material lodging other total1 tutor gift service eduexp grade level typep typep_mx typep_mn type type_mx type_mn hhid
count if npresch==. & preschool>0 & preschool!=.
count if nsch==. & eduexp>0 & eduexp!=.
count if npresch==. & nsch==.
count if npresch==. & nsch==. & (preschool==0 | preschool==.) & (eduexp==0 | eduexp==.)
drop if npresch==. & nsch==.
sort hhid
save results\eduexp, replace
* this file can be used to check some strange expenses with the "budget share methodology"
collapse (sum) preschool eduexp (mean) typep typep_mx typep_mn type type_mx type_mn, by(hhid)
count if typep_mx!=typep_mn
drop typep_mx typep_mn
count if type_mx!=type_mn
tab typep
tab type_mx type
drop type_mn type
rename type_mx type
label val typep M4A_Q03
label val type M4B_Q15
sort hhid
save temp, replace


**************************************
*****                            *****
*****           HEALTH           *****
*****                            *****
**************************************

use results\hhroster, clear

* we need to correct some values
recode m5a_q14 20000=2000 if hhid==402
recode m5a_q14 12500=1250 if hhid==2909
recode m5a_q14 40000=4000 if hhid==3108
recode m5a_q14 200000=20000 if hhid==3705
recode m5a_q14 12000=1200 if hhid==4003
recode m5a_q14 14000=1400 if hhid==9306
recode m5a_q14 10000=1000 if hhid==10402
recode m5a_q14 15000=1500 if hhid==12205
recode m5a_q14 11500=1150 if hhid==22802
recode m5a_q14 8500=850 if hhid==29701
recode m5a_q14 2000=200 if hhid==31902
* 2 corrections
recode m5a_q14 12000=1200 if hhid==33006
recode m5a_q14 20000=2000 if hhid==33901
recode m5a_q14 10000=1000 if hhid==34401
recode m5a_q14 10000=1000 if hhid==36504

egen pambul=rsum(m5a_q14 m5a_q15 m5a_q18 m5a_q20 m5a_q21)
sum pambul if pambul>0, det
list hhid m1_q00 m5a_q14 m5a_q15 m5a_q18 m5a_q20 m5a_q21 if pambul>=10000

recode m5a_q24 40000=4000 if hhid==4003
recode m5a_q28 20000=30000 if hhid==4003
recode m5a_q24 13000=1300 if hhid==20807
recode m5a_q24 10000=1000 if hhid==28001
recode m5a_q24 20000=2000 if hhid==31801
recode m5a_q24 10000=1000 if hhid==36504

egen pdoctor=rsum(m5a_q24 m5a_q25 m5a_q27 m5a_q28 m5a_q29)
sum pdoctor if pdoctor>0, det
list hhid m1_q00 m5a_q24 m5a_q25 m5a_q27 m5a_q28 m5a_q29 if pdoctor>=10000

recode m5a_q32 11000=1100 if hhid==2909

egen nurse=rsum(m5a_q32 m5a_q33 m5a_q35 m5a_q36 m5a_q37)
sum nurse if nurse>0, det
list hhid m1_q00 m5a_q32 m5a_q33 m5a_q35 m5a_q36 m5a_q37 if nurse>=10000

recode m5a_q40 20000=2000 if hhid==3004
recode m5a_q40 20000=2000 if hhid==8906

egen popdoct=rsum(m5a_q40 m5a_q41 m5a_q43 m5a_q44 m5a_q45)
sum popdoct if popdoct>0, det
list hhid m1_q00 m5a_q40 m5a_q41 m5a_q43 m5a_q44 m5a_q45 if popdoct>=10000

rename m5a_q47 medic_wp
sum medic_wp if medic_wp>0, det
list hhid m1_q00 medic_wp if medic_wp>=10000 & medic_wp!=.

egen hospital=rsum(m5a_q53 m5a_q54 m5a_q56 m5a_q57 m5a_q58)
replace hospital=hospital/12
sum hospital if hospital>0, det
list hhid m1_q00 m5a_q53 m5a_q54 m5a_q56 m5a_q57 m5a_q58 if hospital>=10000

recode m5a_q61 999997=3000 if hhid==26309
recode m5a_q65 0=500 if hhid==26309

egen dentist=rsum(m5a_q61 m5a_q62 m5a_q64 m5a_q65 m5a_q66)
replace dentist=dentist/12
sum dentist if dentist>0, det
list hhid m1_q00 m5a_q61 m5a_q62 m5a_q64 m5a_q65 m5a_q66 if dentist>=10000

egen healthexp=rsum(pambul pdoctor nurse popdoct medic_wp hospital dentist)

egen medic=rsum(m5a_q18 m5a_q27 m5a_q35 m5a_q43 medic_wp)
sum m5a_q18 m5a_q27 m5a_q35 m5a_q43 medic_wp
gen medica=m5a_q56/12
gen medicb=m5a_q64/12
sum medica medicb
egen medicine=rsum(medic medica medicb)
gen med_pamb=m5a_q18

rename m5a_q19 medisc
rename m5a_q68 license
replace license=0 if  m5a_q67==2
label def M5A_Q68 0 "no license", add
lab val license M5A_Q68
tab license
count if medisc!=. & license==.

tab license medisc

save temp33, replace

sort hhid
merge hhid using results\base
tab _merge

tab medisc area [aw=weight], col nofreq

collapse (sum) med_pamb medicine healthexp [pw=weight]
dis med_pamb/medicine
dis med_pamb/healthexp
dis medicine/healthexp

use temp33, clear
sort hhid
merge hhid using results\base
tab _merge

gen test=medicine/healthexp
recode test .=0 if healthexp>0
table license [aw=weight], c(m test med test n test) row
table m5a_q67 [aw=weight], c(m test med test n test) row

* impact of medicines
table m5a_q67 [aw=weight], c(m med_pamb med  med_pamb n  med_pamb)
table m5a_q67 [aw=weight], c(m medic_wp med  medic_wp n  medic_wp)
table m5a_q67 [aw=weight], c(m medica med  medica n  medica)
table m5a_q67 [aw=weight], c(m medicb med  medicb n  medicb)

gen med_pamb1=med_pamb
recode med_pamb1 .=0 if healthexp>0
drop test
gen test=med_pamb1/healthexp
recode test .=0 if healthexp>0
table m5a_q67 [aw=weight], c(m test med test n test) row
table license [aw=weight], c(m test med test n test) row

table license [aw=weight], c(m med_pamb med  med_pamb n  med_pamb) 
table license [aw=weight], c(m medic_wp med  medic_wp n  medic_wp) 
table license [aw=weight], c(m medica med  medica n  medica)
table license [aw=weight], c(m medicb med  medicb n  medicb)

use temp33, clear
for var pambul-dentist: recode X 0=.
sum pambul pdoctor nurse popdoct medic_wp hospital dentist

rename m5a_q12 health1
rename m5a_q22 health2
rename m5a_q30 health3
rename m5a_q38 health4
rename m5a_q46 health5
rename m5a_q48 health6
rename m5a_q59 health7
local i=1
while `i'<=7 {
recode health`i' 2=0
local i=`i'+1
}
egen health=rsum(health1 health2 health3 health4 health5 health6 health7)
tab health

gen nlicense=1 if m5a_q67==1
gen hhsize=1

keep hhid m5a_q14 m5a_q15 m5a_q18 m5a_q20 m5a_q21 m5a_q24 m5a_q25 m5a_q27 m5a_q28 m5a_q29 m5a_q32 m5a_q33 m5a_q35 m5a_q36 m5a_q37 /*
*/ m5a_q40 m5a_q41 m5a_q43 m5a_q44 m5a_q45 medic_wp m5a_q53 m5a_q54 m5a_q56 m5a_q57 m5a_q58 m5a_q61 m5a_q62 m5a_q64 m5a_q65 m5a_q66 /*
*/ hhsize pambul pdoctor nurse popdoct medic_wp hospital dentist healthexp medicine nlicense health health1 health2 health3 health4 health5 health6 health7

count if health==0 & healthexp>0 & healthexp!=.
count if health==0 & (healthexp==0 | healthexp==.)
sort hhid
save results\healthexp, replace
* this file can be used to check strange values singled out with the "budget share method"

use results\healthexp, clear

collapse (sum) hhsize pambul pdoctor nurse popdoct medic_wp hospital dentist healthexp medicine nlicense health health1 health2 health3 health4 health5 health6 health7, by(hhid)

sort hhid
merge hhid using data\health_b
tab _merge
drop _merge
sort hhid
merge hhid using results\base
tab _merge
drop _merge

count if healthexp==0
gen med_sh=medicine/healthexp
table nlicense, c(m med_sh med med_sh n med_sh) row
sum healthexp, det
gen healexp_pc=healthexp/hhsize
sum healexp_pc, det

gen test=1 if health==0 & (m5b_q01==1 | m5b_q01==2)

table m5b_q01, c(m healexp_pc med healexp_pc n healexp_pc)

drop hh-m5b_q10
sort hhid
merge hhid using temp
tab _merge
drop _merge
sort hhid
save results\healthedu, replace

!del temp*.dta
