*** Paasche price index for psu

clear
set mem 30m

** Program to calculate the Paasche Index by psu

** 0. To make sure that each household consumes at least 5 different food items
** 1. To obtain the budget share of each food item per psu
** 2. To obtain the implicit price paid for each food item per psu
** 3. To obtain the reference price (median price of each food item at national level)
** 4. To normalize and calculate the index: sum of (1*ln(2/3))

** 0.

use "results\prices.dta", clear
gen one=1
egen nobs=sum(one), by(hhid)
count if nobs==.
tab nobs if nobs<30
* ok!

collapse (mean) area, by(psu)
tab area
* we have 450 psu, we should make sure that these are kept

use results\hhroster, clear
gen hhsize=1
collapse (sum) hhsize, by(hhid)
sort hhid
save temp, replace

use "results\base", clear
sort hhid
merge hhid using temp
tab _merge
drop _merge
sort hhid
merge hhid using results\prices
tab _merge
* _merge=1 : this household might have been excluded because it only consumes food bought outside;
keep if _merge==3
drop _merge
collapse (mean) stratum prefect urbrur area psu weight hhsize, by(hhid)
gen pweight=weight*hhsize
egen totpop=sum(pweight)
egen pop_pr=sum(pweight), by(stratum urbrur)
egen pop_psu=sum(pweight), by(psu)
sort hhid
save temp1, replace

gen one=1
collapse (sum) one, by(psu)
summ one
* ok, we have 450 psu

use temp1, clear
merge hhid using results\prices
tab _merge
drop _merge
save tempor, replace


** 1.

* calculate budget shares (average by population)
use tempor, clear
rename foodexp consi
label var consi "Consumption per item"
egen double const=sum(consi), by(hhid)
label var const "Total Consumption per household"
gen double wi=consi/const
replace wi=wi*pweight
collapse (sum) wi (mean) pop_psu, by(psu itc)
gen wipsu=wi/pop_psu
label var wipsu "Budget share of item by psu"
summ
* just to check
egen totsh=sum(wipsu), by(psu)
summ totsh
compress
drop totsh wi
sort psu itc
save temp1, replace

** 2.

* calculate median prices by psu
use tempor, clear
collapse (mean) psuprice, by(psu itc)
label var psuprice "Implicit price per food item per psu"
summ
compress
sort psu itc
save temp2, replace

** 3.

* to calculate the price of each food item at a national level using weights
use tempor, clear
drop p0
collapse (mean) p0=psuprice [pweight=weight], by(itc)
label var p0 "Price of each food item (national level)"
summ
compress
sort itc
save temp3, replace

clear
set mem 10m

** 4.

use results\base, clear
keep hhid area stratum urbrur prefect psu weight
sort psu
save temp4, replace

use temp1, clear
merge psu itc using temp2
tab _merge
drop _merge
sort itc
merge itc using temp3
tab _merge
drop _merge
sort psu itc
save results\bshares, replace
gen double lnindex= wipsu*log(psuprice/p0)
collapse (sum) lnindex, by(psu)
gen psupind=exp(lnindex)
label var psupind "Paasche Index by psu"
drop lnindex
summ
merge psu using temp4
tab _merge
drop _merge
sort hhid
summ psupind [weight=weight]
gen norm=_result(3)
replace psupind=psupind/norm
label var  psupind "Paasche Index by Household (normalized)"
drop norm
compress
sort hhid
save results\psupind.dta, replace
* to obtain the average Paasche Index by region (urban/rural) and province
table stratum urbrur [pweight=weight], c(mean psupind) row col
table area [pweight=weight], c(mean psupind) row col


! del temp*.dta


