* This file produces poverty estimates, tests the statistical significance of some differences and provides cumulative functions

use results\hhroster, clear
rename m1_q05y age
gen child5=1 if age<=5
gen child6_15=1 if age>=6 & age<15
gen adult=1 if age>=15 & age<=59
gen elder=1 if age>=60
gen hhsize=1
collapse (sum) hhsize child5 child6_15 adult elder, by(hhid)
egen test=rsum(child5 child6_15 adult elder)
count if test!=hhsize
drop test
sort hhid
save temp, replace
use results\totcons, clear
drop pambul-nlicense decile1 decile3 pcons pcons2 totcons totcons2 cumul1-cumul4 foodpc
rename decile4 decile3
rename decile2 decile1
label var decile3 "without rent"
sort hhid
merge hhid using results\psupind
tab _merge
drop if _merge==2
drop _merge
sort hhid
merge hhid using temp
tab _merge
drop if _merge==2
drop _merge
gen rpcons1=totcons1/(psupind*hhsize)
label var rpcons1 "with rent"
egen child=rsum(child5 child6_15)
gen hhsize1=1+0.7*(hhsize-child-1)+child*0.5
label var hhsize1 "OECD scale"
gen rpcons=totcons1/(psupind*hhsize1)
label var rpcons "OECD scale"
gen rpcons3=totcons3/(psupind*hhsize)
label var rpcons3 "without rent"
gen one=1
sort one
merge one using results\povline
tab _merge
drop _merge

label var weight "household weight"
label var pweight "pop weight"

rename rent1 rent
rename waterb water

cumul rpcons3 [aweight=pweight], gen(cumul)
label var cumul "CDF for the whole country"
cumul rpcons3 if area==1 [aweight=pweight], gen(tirana)
label var tirana "CDF for Tirana"
cumul rpcons3 if area==2 [aweight=pweight], gen(urban)
label var urban "CDF for other urban"
cumul rpcons3 if area==3 [aweight=pweight], gen(rural)
label var rural "CDF for rural"
cumul rpcons3 if stratum==1 [aweight=pweight], gen(coastal)
label var coastal "CDF for coastal"
cumul rpcons3 if stratum==2 [aweight=pweight], gen(central)
label var central "CDF for central"
cumul rpcons3 if stratum==3 [aweight=pweight], gen(mountain)
label var mountain "CDF for mountain"

sort hhid
save results\poverty, replace
 

******************************************************
***                                                ***
***    Poverty estimates per capita without rent   ***
***                                                ***
******************************************************

use results\poverty, clear
gen poor50med3=100 if rpcons3<medcon50_3
gen poor3=100 if rpcons3<povline3
gen extpoor3=100 if rpcons3<foodpline
gen poor3ppp2=100 if rpcons3<ppp2
gen poor3ppp4=100 if rpcons3<ppp4
for var poor50med3-poor3ppp4: recode X .=0

log using results\poverty.log, replace

table area [pw=pweight], c(m rpcons3) row

table area [pw=pweight], c(m poor3 m extpoor3 m poor50med3 m poor3ppp2 m poor3ppp4) row

log off

****************************************************
***                                              ***
***    Poverty estimates per capita with rent    ***
***                                              ***
****************************************************

gen poor50med1=100 if rpcons1<medcon50_1
gen poor1=100 if rpcons1<povline1
gen extpoor1=100 if rpcons1<foodpline
gen poor1ppp2=100 if rpcons1<ppp2
gen poor1ppp4=100 if rpcons1<ppp4
for var poor50med1-poor1ppp4: recode X .=0

table area [pw=pweight], c(m poor1 m extpoor1 m poor50med1 m poor1ppp2 m poor1ppp4) row


***************************************************************
***                                                         ***
***   poverty measures, we use the aggregate without rent   ***
***                                                         ***
***************************************************************

* Next line WMT
*rename poor3 poor
g poor = poor3
gen povgap=(povline3-rpcons3)/povline3 if poor==100
recode povgap .=0
replace povgap=povgap*100
gen sevpov=((povline3-rpcons3)/povline3)^2 if poor==100
recode sevpov .=0
replace sevpov=sevpov*100

log on

table area [pw=pweight], c(m poor m povgap m sevpov m rpcons3) col row
table strat [pw=pweight], c(m poor m povgap m sevpov m rpcons3) col row

log off
* Next line WMT
* rename extpoor3 extpoor
g extpoor = extpoor3
gen epovgap=(foodpline-rpcons3)/foodpline if extpoor==100
recode epovgap .=0
replace epovgap=epovgap*100
gen esevpov=((foodpline-rpcons3)/foodpline)^2 if extpoor==100
recode esevpov .=0
replace esevpov=esevpov*100

log on

table area [pw=pweight], c(m extpoor m epovgap m esevpov) col row
table strat [pw=pweight], c(m extpoor m epovgap m esevpov) col row

*ineqdeco rpcons3 [aw=pweight], by(area)
*ineqdeco rpcons3 [aw=pweight], by(strat)
log close


*** Cumulative functions


#delimit ;
graph cumul rpcons3 if rpcons3<10000, c(l) s(.) xline(4891) sort
  xlabel(2000, 4000, 6000, 8000, 10000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr


#delimit ;
graph tirana urban rural rpcons3 if rpcons3<10000, c(lll) s(...) xline(4891) sort
  xlabel(2000, 4000, 6000, 8000, 10000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr


#delimit ;
graph tirana coastal central mountain rpcons3 if rpcons3<10000, c(llll) s(....) xline(4891) sort
  xlabel(2000, 4000, 6000, 8000, 10000)
  ylabel(0, .2, .4, .6, .8)
  l2title("fraction of population")
  b2title("real per capita consumption");
#delimit cr

* Next line WMT
drop poor
save, replace

