* This file calculates a food poverty line

clear
set mem 20m

******************************************
***                                    ***
***          FOOD POVERTY LINE         ***
***                                    ***
******************************************

* 1) we only take the poorer 50% of the population, according to the per adult equivalent total consumption
* 2) we calculate mean per adult equivalent quantity consumed (food expenditure/median psu price)
* 3) we transform quantities in calories terms
* 4) we adjust that basket to understand how much costs to get 2288 calories per day per month (FAO estimates adjusted for Albanian population distribution)


* step n.1

use results\hhroster, clear
gen hhsize=1
collapse (sum) hhsize, by(hhid)
sort hhid
save temp, replace

use results\totcons, clear
sort hhid
merge hhid using results\psupind
tab _merge
drop _merge
sort hhid
merge hhid using temp
tab _merge
drop _merge
gen rpcons=totcons/(psupind*hhsize)

* we work with per capita values
cumul rpcons [aw=pweight], gen(cumul)
gen decile=1
replace decile=2 if cumul>0.1
replace decile=3 if cumul>0.2
replace decile=4 if cumul>0.3
replace decile=5 if cumul>0.4
replace decile=6 if cumul>0.5
replace decile=7 if cumul>0.6
replace decile=8 if cumul>0.7
replace decile=9 if cumul>0.8
replace decile=10 if cumul>0.9

save temp333, replace

* First hypothesis (bottom 50%)

use temp333, clear
keep if cumul<=0.5
keep hhid hhsize pweight
egen totpop=sum(pweight)
sort hhid
save temp, replace


* step n.2

use results\calories, clear
sort itc
save, replace
use results\prices, clear
sort hhid
merge hhid using temp
tab _merge
keep if _merge==3
drop _merge
gen pcquant=((foodexp/psuprice)/hhsize)/totpop
collapse (sum) pcquant (mean) p0 unit subgroup [pw=pweight], by(itc)


* step n. 3

gen value=p0*pcquant
egen totvalue=sum(value)
gen share=100*value/totvalue
gsort -share
gen cumshare=sum(share)
keep if share>=0.11
sum cumshare
gen totshare=r(max)
sum totshare
* 59 items account for 97.6% of total food expenditure 
table itc, c(m unit)
sort itc
merge itc using results\calories
tab _merge
drop if _merge==2
drop _merge
gen calunit=calories/100 if unit==1
replace calunit=calories*10 if unit==2 | unit==4
replace calunit=calories if unit==3


* step n. 4

gen calquant=calunit*pcquant
egen cal_npd=sum(calquant)
egen cal_cost=sum(value)
replace cal_npd=cal_npd/14
replace cal_cost=cal_cost/14
sum cal_npd cal_cost

* calories obtained by these people are
sum totshare
dis cal_npd/(r(mean)/100)
dis cal_cost/(r(mean)/100)

gen costpcal=cal_cost/cal_npd
gen foodpline=(costpcal*2288)*30.416667
sum foodpline
keep if itc==1
rename foodpline foodpl1_5
keep foodpl1_5
gen one=1
sort one
save foodpl1_5, replace


* Second hypothesis (2-5 deciles)

use temp333, clear
keep if cumul>0.1 & cumul<=0.5
keep hhid hhsize pweight
egen totpop=sum(pweight)
sort hhid
save temp, replace

* step n.2

use results\calories, clear
sort itc
save, replace
use results\prices, clear
sort hhid
merge hhid using temp
tab _merge
keep if _merge==3
drop _merge
gen pcquant=((foodexp/psuprice)/hhsize)/totpop
collapse (sum) pcquant (mean) p0 unit subgroup [pw=pweight], by(itc)


* step n. 3

gen value=p0*pcquant
egen totvalue=sum(value)
gen share=100*value/totvalue
gsort -share
gen cumshare=sum(share)
keep if share>=0.11
sum cumshare
gen totshare=r(max)
sum totshare
table itc, c(m unit)
sort itc
merge itc using results\calories
tab _merge
drop if _merge==2
drop _merge
gen calunit=calories/100 if unit==1
replace calunit=calories*10 if unit==2 | unit==4
replace calunit=calories if unit==3


* step n. 4

gen calquant=calunit*pcquant
egen cal_npd=sum(calquant)
egen cal_cost=sum(value)
replace cal_npd=cal_npd/14
replace cal_cost=cal_cost/14
sum cal_npd cal_cost

* calories obtained by these people are
sum totshare
dis cal_npd/(r(mean)/100)
dis cal_cost/(r(mean)/100)

gen costpcal=cal_cost/cal_npd
gen foodpline=(costpcal*2288)*30.416667
sum foodpline
keep if itc==1
rename foodpline foodpl2_5
keep foodpl2_5
gen one=1
sort one
save foodpl2_5, replace



* Third hypothesis (2-4 deciles)

use temp333, clear
keep if cumul>0.1 & cumul<=0.4
keep hhid hhsize pweight
egen totpop=sum(pweight)
sort hhid
save temp, replace

* step n.2

use results\calories, clear
sort itc
save, replace
use results\prices, clear
sort hhid
merge hhid using temp
tab _merge
keep if _merge==3
drop _merge
gen pcquant=((foodexp/psuprice)/hhsize)/totpop
collapse (sum) pcquant (mean) p0 unit subgroup [pw=pweight], by(itc)


* step n. 3

gen value=p0*pcquant
egen totvalue=sum(value)
gen share=100*value/totvalue
gsort -share
gen cumshare=sum(share)
keep if share>=0.11
sum cumshare
gen totshare=r(max)
sum totshare
table itc, c(m unit)
sort itc
merge itc using results\calories
tab _merge
drop if _merge==2
drop _merge
gen calunit=calories/100 if unit==1
replace calunit=calories*10 if unit==2 | unit==4
replace calunit=calories if unit==3


* step n. 4

gen calquant=calunit*pcquant
egen cal_npd=sum(calquant)
egen cal_cost=sum(value)
replace cal_npd=cal_npd/14
replace cal_cost=cal_cost/14
sum cal_npd cal_cost

gen valuepd=value/14
gen calpd=calquant/14
gen quantpd=pcquant/14
table subgroup, c(sum valuepd sum calpd sum quantpd mean unit) row

*** these are the calorie contents of the poverty line

* calories obtained by these people are
sum totshare
dis cal_npd/(r(mean)/100)
dis cal_cost/(r(mean)/100)


gen costpcal=cal_cost/cal_npd
gen foodpline=(costpcal*2288)*30.416667
sum foodpline
keep if itc==1
rename foodpline foodpl2_4
keep foodpl2_4
gen one=1
sort one
merge one using foodpl1_5
drop _merge
sort one
merge one using foodpl2_5
drop _merge
sum foodp*
rename foodpl2_4 foodpline
keep one foodpline
sort one
save results\foodpline, replace

!del foodp*.dta


******************************************
***                                    ***
***         TOTAL POVERTY LINE         ***
***                                    ***
******************************************

use results\hhroster, clear
count if m1_q05y==.
tab m1_q05y
rename m1_q05y age
gen child5=1 if age<=5
gen child6_15=1 if age>=6 & age<15
gen adult=1 if age>=15 & age<=59
gen elder=1 if age>=60
gen hhsize=1
collapse (sum) hhsize child5 child6_15 adult elder, by(hhid)
egen test=rsum(child5 child6_15 adult elder)
count if test!=hhsize
drop test
sort hhid
save temp, replace
use results\totcons, clear
sort hhid
merge hhid using results\psupind
tab _merge
drop if _merge==2
drop _merge
sort hhid
merge hhid using temp
tab _merge
drop if _merge==2
drop _merge
gen rpcons1=totcons1/(psupind*hhsize)
label var rpcons1 "with rent"
egen child=rsum(child5 child6_15)
gen hhsize1=1+0.7*(hhsize-child-1)+child*0.5
label var hhsize1 "OECD scale"
gen rpcons=totcons1/(psupind*hhsize1)
label var rpcons "OECD scale"
gen rpcons3=totcons3/(psupind*hhsize)
label var rpcons3 "without rent"
gen one=1
sort one
merge one using results\foodpline
tab _merge
drop _merge

gen hhsize2=adult+0.5*child5+0.8*(child6_15+elder)
gen peafood1=food/hhsize2
gen peafood=food/hhsize1
gen pcfood=food/hhsize

* calculation of poverty line with rent

gen nfoodsh=(totcons1-food)/totcons1

sum nfoodsh if pcfood>0.95*foodpline & pcfood<1.05*foodpline [aw=weight]
sum nfoodsh if pcfood>0.9*foodpline & pcfood<1.1*foodpline [aw=weight]
sum nfoodsh if pcfood>0.85*foodpline & pcfood<1.15*foodpline [aw=weight]
sum nfoodsh if pcfood>0.8*foodpline & pcfood<1.2*foodpline [aw=weight]

gen povline1=foodpline/(1-r(mean))
label var povline1 "with rent"

* calculation of poverty line without rent

gen nfoodsh1=(totcons3-food)/totcons3
sum nfoodsh1 if pcfood>0.95*foodpline & pcfood<1.05*foodpline [aw=weight]
sum nfoodsh1 if pcfood>0.9*foodpline & pcfood<1.1*foodpline [aw=weight]
sum nfoodsh1 if pcfood>0.85*foodpline & pcfood<1.15*foodpline [aw=weight]
sum nfoodsh1 if pcfood>0.8*foodpline & pcfood<1.2*foodpline [aw=weight]

gen povline3=foodpline/(1-r(mean))
label var povline3 "without rent"

sum povline1 povline3

* calculation of extreme poverty line (Gero methodology) only for aggregate without rent

sum nfoodsh1 if rpcons3>0.95*foodpline & rpcons3<1.05*foodpline [aw=weight]
sum nfoodsh1 if rpcons3>0.9*foodpline & rpcons3<1.1*foodpline [aw=weight]
sum nfoodsh1 if rpcons3>0.85*foodpline & rpcons3<1.15*foodpline [aw=weight]
sum nfoodsh1 if rpcons3>0.8*foodpline & rpcons3<1.2*foodpline [aw=weight]

gen extpline3=foodpline/(1-r(mean))
label var extpline3 "extreme poverty line without rent - Gero's method"


******************************************
***                                    ***
***      50% of median consumption     ***
***                                    ***
******************************************

sum rpcons1 [aw=pweight], det
gen medcon50_1=r(p50)/2
sum medcon50_1
label var medcon50_1 "50% of median with rent"

sum rpcons3 [aw=pweight], det
gen medcon50_3=r(p50)/2
sum medcon50_3
label var medcon50_3 "50% of median without rent"

* 1, 2 and 4 dollars per day

gen ppp1=1887
label var ppp1 "1 dollar"
gen ppp2=3775
label var ppp2 "2 dollars"
gen ppp4=7549
label var ppp4 "4 dollars"

keep one foodpline povline1 povline3 extpline3 medcon50_1 medcon50_3 ppp1 ppp2 ppp4
keep if _n==1
sort one
save results\povline, replace


