*** This file prepare prices

clear
set mem 40m

* We need to have only one unit of measurement for each item, so that we need to take into consideration transactions that are expressed in the wanted unit of
* measurement. As long as for each item and in each psu, where that item is bought at least by one household, we have a price (calculated with the most common
* unit of measurement) we are fine.

* We try the following procedure:
* 1) drop some problematic items 
* 2) calculate psu price, and eventually substitute missing prices with median price in the same area.
* 3) corrrect some unit of measurement, and transform some unit of measuremnt to increase unit mode observations.
* 4) recalculate psu price, and eventually substitute remaining missing prices with median price in the same area. 
* 5) compare psu prices before an after correction of units and decide which one to use
* 6) check psu prices and decide whether to drop some items

use results\food1, clear
count if foodexp1==0
drop if foodexp1==0
drop euvalue1

*** Step n.1

* cleaning of unnecessary variables
drop if value==. & quant==.
drop uvalue
gen uvalue=foodexp1/quant1
* we drop all items of food eaten outside for which we do not have quantities
drop if subgroup==14
egen euvalue1=median(uvalue), by(psu itc)

* most frequent unit
tab itc if umode==.
drop if umode==.


*** Step n.2

count if unit!=umode
gen c_unit=uvalue if unit==umode
egen psu_unit=median(c_unit), by(psu itc)
egen pre_unit=median(c_unit), by(prefect urbrur itc)
count if psu_unit==. & pre_unit==.
replace psu_unit=pre_unit if psu_unit==.
egen are_unit=median(c_unit), by(stratum urbrur itc)
count if psu_unit==. & are_unit==.
replace psu_unit=are_unit if psu_unit==.
egen ara_unit=median(c_unit), by(area itc)
count if psu_unit==. & ara_unit==.
replace psu_unit=ara_unit if psu_unit==.
egen tot_unit=median(c_unit), by(itc)
count if psu_unit==. & tot_unit==.
replace psu_unit=tot_unit if psu_unit==.
drop if psu_unit==.

drop c_unit pre_unit are_unit ara_unit tot_unit


*** Step n.3

* try to understand the scale of the problem
gen one=1
gen test=1 if unit!=umode
egen nitems=sum(one), by(itc)
egen chunit=sum(test), by(itc)
drop test one
table itc, c(m nitems m chunit)

* we try to identify cases where there is a clear mistake in the reported unit of measurement

* the same household reports expenses with the same unit values but with wrong unit of measurement
egen uvalue1=median(uvalue) if unit==umode, by(hhid itc) 
egen uvalue11=max(uvalue1), by(hhid itc)
count if uvalue11==.
gen test=uvalue/uvalue11 if unit!=umode
sum test, det
count if test>=0.8 & test<=1.2 & unit!=umode
tab unit umode if test>=0.8 & test<=1.2 & unit!=umode
replace unit=umode if test>=0.8 & test<=1.2 & unit!=umode
count if unit!=umode
drop test uvalue1 uvalue11

* in the same psu there are households reporting expenses with the same unit values but with wrong unit of measurement
egen uvalue1=median(uvalue) if unit==umode, by(psu itc) 
egen uvalue11=max(uvalue1), by(psu itc)
count if uvalue11==.
gen test=uvalue/uvalue11 if unit!=umode
sum test, det
count if test>=0.8 & test<=1.2 & unit!=umode
tab unit umode if test>=0.8 & test<=1.2 & unit!=umode
replace unit=umode if test>=0.8 & test<=1.2 & unit!=umode
count if unit!=umode
drop test uvalue1 uvalue11

* in the same prefecture and urban/rural area households reporting expenses with the same unit values but with wrong unit of measurement
egen uvalue1=median(uvalue) if unit==umode, by(prefect urbrur itc) 
egen uvalue11=max(uvalue1), by(prefect urbrur itc)
count if uvalue11==.
gen test=uvalue/uvalue11 if unit!=umode
sum test, det
count if test>=0.8 & test<=1.2 & unit!=umode
tab unit umode if test>=0.8 & test<=1.2 & unit!=umode
replace unit=umode if test>=0.8 & test<=1.2 & unit!=umode
count if unit!=umode
drop test uvalue1 uvalue11

* in the area households reporting expenses with the same unit values but with wrong unit of measurement
egen uvalue1=median(uvalue) if unit==umode, by(stratum urbrur itc) 
egen uvalue11=max(uvalue1), by(stratum urbrur itc)
count if uvalue11==.
gen test=uvalue/uvalue11 if unit!=umode
sum test, det
count if test>=0.8 & test<=1.2 & unit!=umode
tab unit umode if test>=0.8 & test<=1.2 & unit!=umode
replace unit=umode if test>=0.8 & test<=1.2 & unit!=umode
count if unit!=umode
drop test uvalue1 uvalue11

* in the area households reporting expenses with the same unit values but with wrong unit of measurement
egen uvalue1=median(uvalue) if unit==umode, by(area itc) 
egen uvalue11=max(uvalue1), by(area itc)
count if uvalue11==.
gen test=uvalue/uvalue11 if unit!=umode
sum test, det
count if test>=0.8 & test<=1.2 & unit!=umode
tab unit umode if test>=0.8 & test<=1.2 & unit!=umode
replace unit=umode if test>=0.8 & test<=1.2 & unit!=umode
count if unit!=umode
drop test uvalue1 uvalue11

* in the area households reporting expenses with the same unit values but with wrong unit of measurement
egen uvalue1=median(uvalue) if unit==umode, by(itc) 
egen uvalue11=max(uvalue1), by(itc)
count if uvalue11==.
gen test=uvalue/uvalue11 if unit!=umode
sum test, det
count if test>=0.8 & test<=1.2 & unit!=umode
tab unit umode if test>=0.8 & test<=1.2 & unit!=umode
replace unit=umode if test>=0.8 & test<=1.2 & unit!=umode
count if unit!=umode
drop test uvalue1 uvalue11

* items are reported already with the mode unit, but there is a mistake between grams and kg, again this correction can be done at different levels

gen uv_gram=euvalue1 if unit==1
egen uv_grams=median(uv_gram), by(psu itc)
gen uv_kilo=euvalue1 if unit==2
egen uv_kilos=median(uv_kilo), by(psu itc)
gen t_grams=uvalue/uv_grams if unit==1
gen t_kilos=uvalue/uv_kilos if unit==2

count if unit==1 & t_grams>=800 & t_grams<=1200
count if unit==2 & t_kilos>=0.0008 & t_kilos<=0.0012
replace unit=2 if t_grams>=800 & t_grams<=1200 & unit==1
replace unit=1 if t_kilos>=0.0008 & t_kilos<=0.0012 & unit==2

drop uv_grams uv_kilos t_grams t_kilos

egen uv_grams=median(uv_gram), by(prefect urbrur itc)
egen uv_kilos=median(uv_kilo), by(prefect urbrur itc)
gen t_grams=uvalue/uv_grams if unit==1
gen t_kilos=uvalue/uv_kilos if unit==2

count if unit==1 & t_grams>=800 & t_grams<=1200
count if unit==2 & t_kilos>=0.0008 & t_kilos<=0.0012
replace unit=2 if t_grams>=800 & t_grams<=1200 & unit==1
replace unit=1 if t_kilos>=0.0008 & t_kilos<=0.0012 & unit==2

drop uv_grams uv_kilos t_grams t_kilos

egen uv_grams=median(uv_gram), by(stratum urbrur itc)
egen uv_kilos=median(uv_kilo), by(stratum urbrur itc)
gen t_grams=uvalue/uv_grams if unit==1
gen t_kilos=uvalue/uv_kilos if unit==2

count if unit==1 & t_grams>=800 & t_grams<=1200
count if unit==2 & t_kilos>=0.0008 & t_kilos<=0.0012
replace unit=2 if t_grams>=800 & t_grams<=1200 & unit==1
replace unit=1 if t_kilos>=0.0008 & t_kilos<=0.0012 & unit==2

drop uv_grams uv_kilos t_grams t_kilos

egen uv_grams=median(uv_gram), by(area itc)
egen uv_kilos=median(uv_kilo), by(area itc)
gen t_grams=uvalue/uv_grams if unit==1
gen t_kilos=uvalue/uv_kilos if unit==2

count if unit==1 & t_grams>=800 & t_grams<=1200
count if unit==2 & t_kilos>=0.0008 & t_kilos<=0.0012
replace unit=2 if t_grams>=800 & t_grams<=1200 & unit==1
replace unit=1 if t_kilos>=0.0008 & t_kilos<=0.0012 & unit==2

drop uv_grams uv_kilos t_grams t_kilos

egen uv_grams=median(uv_gram), by(itc)
egen uv_kilos=median(uv_kilo), by(itc)
gen t_grams=uvalue/uv_grams if unit==1
gen t_kilos=uvalue/uv_kilos if unit==2

count if unit==1 & t_grams>=800 & t_grams<=1200
count if unit==2 & t_kilos>=0.0008 & t_kilos<=0.0012
replace unit=2 if t_grams>=800 & t_grams<=1200 & unit==1
replace unit=1 if t_kilos>=0.0008 & t_kilos<=0.0012 & unit==2

drop uv_gram uv_grams uv_kilo uv_kilos t_grams t_kilos

* we can now convert grams into kg when kg is the unit mode and kg into grams when grams is the unit mode

* Grams is the unit mode, so we transform kgs into grams
gen change1=1 if umode==1 & unit==2
replace quant1=quant1*1000 if change1==1
replace uvalue=uvalue/1000 if change1==1
replace unit=1 if change1==1

* Kg is the unit mode, so we transform grams into kgs
gen change2=1 if umode==2 & unit==1
replace quant1=quant1/1000 if change2==1
replace uvalue=uvalue*1000 if change2==1
replace unit=2 if change2==1

drop change1 change2

* check which items are still particularly problematic
count if unit!=umode
drop chunit
gen test=1 if unit!=umode
egen chunit=sum(test), by(itc)
drop test
table itc, c(m nitems m chunit)
gen percent=chunit/nitems
tab percent

table itc if percent>=0.2, c(m percent n percent) 
tab itc unit if percent>=0.2


*** Step n. 4

gen c_unit=uvalue if unit==umode
egen psu_unit1=median(c_unit), by(psu itc)
egen pre_unit=median(c_unit), by(prefect urbrur itc)
count if psu_unit1==. & pre_unit==.
replace psu_unit1=pre_unit if psu_unit1==.
egen are_unit=median(c_unit), by(stratum urbrur itc)
count if psu_unit1==. & are_unit==.
replace psu_unit1=are_unit if psu_unit1==.
egen ara_unit=median(c_unit), by(area itc)
count if psu_unit1==. & ara_unit==.
replace psu_unit1=ara_unit if psu_unit1==.
egen tot_unit=median(c_unit), by(itc)
count if psu_unit1==. & tot_unit==.
replace psu_unit1=tot_unit if psu_unit1==.

drop c_unit pre_unit are_unit ara_unit tot_unit


*** Step n. 5

count if psu_unit==psu_unit1
count if psu_unit!=psu_unit1
gen test=psu_unit1/psu_unit
tab test if test<0.8 | test>1.2
egen p0=median(uvalue) if unit==umode, by(stratum urbrur itc)
egen p01=max(p0), by(stratum urbrur itc)

count if test<0.8 | test>1.2
gen diff=psu_unit-p01 if  (test<0.8 | test>1.2)
gen diff1=psu_unit1-p01 if  (test<0.8 | test>1.2)
replace diff=-diff if diff<0
replace diff1=-diff1 if diff1<0
replace psu_unit1=psu_unit if diff<diff1
drop psu_unit diff diff1 p0 p01 test
rename psu_unit1 psuprice


*** Step n. 6

egen p0=median(psuprice), by(area itc)
gen test=psuprice/p0
tab test if test<0.5 | test>1.5
replace psuprice=p0 if test<0.5 | test>1.5
drop p0 test


*** now we only keep the variables we need

keep hhid psu comune urbrur prefect district stratum weight area itc umode subgroup foodexp1 psuprice
egen p0=median(psuprice), by(itc)
collapse (sum) foodexp=foodexp1 (mean) psu-area psuprice p0 subgroup unit=umode, by(hhid itc)
sort hhid
save results\prices, replace


