*** This file aggregates all consumption sources and checks for outliers with the "budget share method".

clear 
set mem 20m

use results\foodexp, clear
sort hhid
merge hhid using results\nfoodexp
tab _merge
drop _merge
sort hhid
merge hhid using results\healthedu
tab _merge
drop _merge
sort hhid
merge hhid using results\utilities
tab _merge
drop _merge
sort hhid
merge hhid using results\durcons
tab _merge
drop _merge

* we drop one household that contain some problem as advised by Alberto
drop if hhid==1610

egen edu=rsum(eduexp preschool)
egen fuel=rsum(firewood-cheat)
egen phone=rsum(phonebill-pubphone)
egen totcons=rsum(food sub1-sub10 edu rent elect fuel waterb phone durcons)

for var food sub1-sub10 edu rent elect fuel water phone durcons: recode X 0=.

* now we compute shares

gen fodsh=food/totcons
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen rensh=rent/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons

* Just to check
egen tot=rsum(fodsh-phosh)
sum tot
drop tot

drop test
sort hhid
save temp, replace

*** Check durables

use temp, clear
egen mdsh=mean(dursh)
egen sddsh=sd(dursh)
gen test=1 if (dursh>mdsh+2*sddsh) & dursh!=.
count if test==1
sum dursh if test==1, d
keep if test==1
keep hhid food totcons test dursh hhsize
sort hhid
save temp1, replace
use results\durables, clear
sort hhid
merge hhid using temp
tab _merge
keep if _merge==3
drop _merge
gen durpc=idurcons/hhsize
egen mean=mean(durpc), by(itc)
sort hhid
merge hhid using temp1
tab _merge
gen share=idurcons/totcons
egen max=max(share), by(hhid)
gen test1=(idurcons/hhsize)/mean
count if test1>10 & max==share & _merge==3
count if test1>5 & max==share & _merge==3
tab itc if test1>5 & max==share & _merge==3
list hhid itc idurcons currvalue dursh share test1 if test1>5 & max==share & _merge==3
gen correct=1 if test1>5 & max==share & _merge==3
gen idurcons1=idurcons
replace idurcons1=((currvalue/10)*deprate) if correct==1
keep hhid itc idurcons idurcons1 currvalue deprate
sort hhid
save results\durables1, replace
gen durcons=idurcons1/12
collapse (sum) durcons, by(hhid)
sum durcons, d
sort hhid
save results\durcons1, replace

*** After these corrections we recalculate again total consumption

use results\foodexp, clear
sort hhid
merge hhid using results\nfoodexp
tab _merge
drop _merge
sort hhid
merge hhid using results\healthedu
tab _merge
drop _merge
sort hhid
merge hhid using results\utilities
tab _merge
drop _merge
sort hhid
merge hhid using results\durcons1
tab _merge
drop _merge
* we drop one household that contain some problem as advised by Alberto
drop if hhid==1610
egen edu=rsum(eduexp preschool)
egen fuel=rsum(firewood-cheat)
egen phone=rsum(phonebill-pubphone)
egen totcons=rsum(food sub1-sub10 edu rent elect fuel waterb phone durcons)
for var food sub1-sub10 edu rent elect fuel water phone durcons: recode X 0=.

* now we compute shares
gen fodsh=food/totcons
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen rensh=rent/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
* Just to check
egen tot=rsum(fodsh-phosh)
sum tot
drop tot
drop test
sort hhid
save temp, replace


*** Check all the subgroups of non food

local i=1
while `i'<=10 {
use temp, clear
egen mssh`i'=mean(ssh`i')
egen sdssh`i'=sd(ssh`i')
gen test=1 if (ssh`i'>mssh`i'+2*sdssh`i') & ssh`i'!=.
count if test==1
sum ssh`i' if test==1, d
keep if test==1
keep hhid food totcons test ssh`i' hhsize
sort hhid
save temp1, replace
use results\nfood, clear
keep if subgroup==`i'
sort hhid
merge hhid using temp
tab _merge
drop if _merge==2
drop _merge
gen nfoodpc=nfood/hhsize
egen mean=mean(nfoodpc), by(code)
sort hhid
merge hhid using temp1
tab _merge
gen share=nfood/totcons
egen max=max(share), by(hhid)
gen test1=(nfood/hhsize)/mean
count if test1>10 & max==share & _merge==3
tab code if test1>10 & max==share & _merge==3
list hhid code nfood ssh`i' share test1 if test1>10 & max==share & _merge==3
gen correct=1 if test1>10 & max==share & _merge==3
gen nfood1=nfood
replace nfood1=nfood1/10 if test1>10 & max==share & _merge==3
keep code hhid nfood nfood1 subgroup correct
sort hhid code
save group`i', replace
local i=`i'+1
}

* we build again non food expenses

use group1, clear
local i=2
while `i'<=10 {
sort hhid code
merge hhid code using group`i'
tab _merge
drop _merge
local i=`i'+1
}

sort hhid code
save temp, replace

* out of those items previously corrected only some of them were confirmed, and 3 items were not corrected
use "results\correct_sect11"
sort hhid code
save, replace

use temp, clear
merge hhid code using "results\correct_sect11"
tab _merge
tab correct _merge
replace nfood1=nfood if correct==1 & _merge==3
recode correct 1=. if _merge==3

*** all together we made 43 corrections
drop _merge
save results\nfood1, replace

collapse (sum) nfood=nfood1, by(hhid subgroup)

gen sub1=nfood if subgroup==1
gen sub2=nfood if subgroup==2
gen sub3=nfood if subgroup==3
gen sub4=nfood if subgroup==4
gen sub5=nfood if subgroup==5
gen sub6=nfood if subgroup==6
gen sub7=nfood if subgroup==7
gen sub8=nfood if subgroup==8
gen sub9=nfood if subgroup==9
gen sub10=nfood if subgroup==10

collapse (sum) sub1-sub10, by(hhid)
sort hhid
save results\nfoodexp1, replace


*** After these corrections we recalculate again total consumption

clear 
set mem 20m

use results\foodexp, clear
sort hhid
merge hhid using results\nfoodexp1
tab _merge
drop _merge
sort hhid
merge hhid using results\healthedu
tab _merge
drop _merge
sort hhid
merge hhid using results\utilities
tab _merge
drop _merge
sort hhid
merge hhid using results\durcons1
tab _merge
drop _merge
* we drop one household that contain some problem as advised by Alberto
drop if hhid==1610
egen edu=rsum(eduexp preschool)
egen fuel=rsum(firewood-cheat)
egen phone=rsum(phonebill-pubphone)
egen totcons=rsum(food sub1-sub10 edu rent elect fuel waterb phone durcons)
for var food sub1-sub10 edu rent elect fuel water phone durcons: recode X 0=.

* now we compute shares
gen fodsh=food/totcons
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen rensh=rent/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
* Just to check
egen tot=rsum(fodsh-phosh)
sum tot
drop tot
drop test
sort hhid
save temp, replace


*** Now we check education

use temp, clear
egen medush=mean(edush)
egen sdedush=sd(edush)
gen test=1 if (edush>medush+2*sdedush) & edush!=.
count if test==1
sum edush if test==1, d
keep if test==1
keep hhid food totcons edu test edush hhsize
sort hhid
save temp1, replace
use results\eduexp, clear
egen edupc=rsum(preschool eduexp)
sort hhid
merge hhid using temp1
tab _merge
gen newtype=1 if typep!=.
replace newtype=2 if type!=.
egen mean=mean(edupc), by(level newtype)
gen share=edupc/totcons
egen max=max(share), by(hhid)
gen test1=edupc/mean
count if test1>10 & max==share & _merge==3

list hhid pfee pgift pservice edush if newtype==1 & test1>10 & max==share & _merge==3

gen correct=1 if newtype==1 & test1>10 & max==share & _merge==3 & pfee==12000
gen preschool1=preschool
replace preschool1=preschool1/10 if newtype==1 & test1>10 & max==share & _merge==3  & pfee==12000

list hhid total1 transport fee-other tutor gift service if newtype==2 & test1>10 & max==share & _merge==3
list hhid total1 transport fee-other tutor edush level if newtype==2 & test1>10 & max==share & _merge==3
list hhid total1 transport fee-other tutor type edush if newtype==2 & test1>10 & max==share & _merge==3

replace correct=1 if newtype==2 & test1>10 & max==share & _merge==3
egen school=rsum(total1 transport fee-other tutor gift service)
replace school=school/12
gen school1=school
replace school1=school1/10 if newtype==2 & test1>10 & max==share & _merge==3
keep hhid school school1 preschool preschool1 correct 
egen edu=rsum(school1 preschool1)
collapse (sum) edu, by(hhid)
sort hhid
save results\edu, replace


*** After these corrections we recalculate again total consumption

clear 
set mem 20m

use results\healthedu, clear
keep hhid hhsize
sort hhid
merge hhid using results\foodexp
tab _merge
drop _merge
sort hhid
merge hhid using results\nfoodexp1
tab _merge
drop _merge
sort hhid
merge hhid using results\edu
tab _merge
drop _merge
sort hhid
merge hhid using results\utilities
tab _merge
drop _merge
sort hhid
merge hhid using results\durcons1
tab _merge
drop _merge
* we drop one household that contain some problem as advised by Alberto
drop if hhid==1610
egen fuel=rsum(firewood-cheat)
egen phone=rsum(phonebill-pubphone)
egen totcons=rsum(food sub1-sub10 edu rent elect fuel waterb phone durcons)
for var food sub1-sub10 edu rent elect fuel water phone durcons: recode X 0=.

* now we compute shares
gen fodsh=food/totcons
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen rensh=rent/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
* Just to check
egen tot=rsum(fodsh-phosh)
sum tot
drop tot
sort hhid
save temp, replace


*** Now we check utilities

** rent

use temp, clear
egen mrensh=mean(rensh)
egen sdrensh=sd(rensh)
gen test=1 if rensh>mrensh+2*sdrensh & rensh!=.
count if test==1
sum rensh if test==1, d
egen mean=mean(rent), by(area)
gen test1=rent/mean
sum rent estrent if test==1 & test1>=5
gen diff=rent-estrent
gen share=diff/rent
sum share if test==1 & test1>=5, d 
sum share if test==1, d
list hhid rent estrent share rensh if share>0.25 & test==1 & test1>=5

* some of these values were already checked and they are fine, but two needs to be corrected
gen correct=1 if share>0.25 & test==1 & test1>=5
gen rent1=rent
replace rent1=estrent if correct==1
keep hhid rent rent1 correct
sort hhid
save util1, replace

* electricity

use temp, clear
egen melesh=mean(elesh)
egen sdelesh=sd(elesh)
gen test=1 if elesh>melesh+2*sdelesh & elesh!=.
count if test==1
sum elesh if test==1, d
egen mean=mean(elect), by(area)
gen test1=elect/mean
sum elect mbill estbiladj if test==1 & test1>=5
gen diff=elect-estbiladj
gen share=diff/elect
sum share if test==1, d 
list hhid urbrur elect elesh estbiladj if share>0.25 & test==1
list hhid urbrur elect elesh estbiladj if share>0.5 & test==1
* we correct these values using the regression estimates
gen correct=1 if share>0.25 & test==1
replace elect=estbiladj if correct==1
keep hhid elect estbiladj mbill
sort hhid
save util2, replace

** fuel

use temp, clear
egen mfuesh=mean(fuesh)
egen sdfuesh=sd(fuesh)
gen test=1 if fuesh>mfuesh+2*sdfuesh & fuesh!=.
count if test==1
sum fuesh if test==1, d
for var gascons firewood coal oilker diesel other cheat: recode X 0=.
gen fuelpc1=gascons/hhsize
gen fuelpc2=firewood/hhsize
gen fuelpc3=coal/hhsize
gen fuelpc4=oilker/hhsize
gen fuelpc5=diesel/hhsize
gen fuelpc6=other/hhsize
gen fuelpc7=cheat/hhsize
local i=1
while `i'<=7 {
egen mean`i'=mean(fuelpc`i') if fuelpc`i'!=.
gen test`i'=fuelpc`i'/mean`i'
local i=`i'+1
}
for var test1 test2 test3 test4 test5 test6 test7: recode X .=0
count if test==1 & (test1>=10 | test2>=10 | test3>=10 | test4>=10 | test5>=10 | test6>=10 | test7>=10)
* corrections
gen correct=1 if test==1 & (test1>=10 | test2>=10 | test3>=10 | test4>=10 | test5>=10 | test6>=10 | test7>=10)

list hhid firewood elect fuel fuesh test2 if correct==1

gen firesh=firewood/totcons
count if firesh>0.1 & firesh!=.
tab urbrur if firesh>0.1 & firesh!=.


keep hhid gascons firewood coal oilker diesel other cheat correct
egen fuel=rsum( gascons firewood coal oilker diesel other cheat)
sort hhid
save util3, replace

** phone

use temp, clear
egen mphosh=mean(phosh)
egen sdphosh=sd(phosh)
gen test=1 if phosh>mphosh+2*sdphosh & phosh!=.
count if test==1
sum phosh if test==1, d
gen phonebpc=phonebill/hhsize
gen mobpc=mobile/hhsize
gen pubpc=pubphone/hhsize
egen mean1=mean(phonebpc) if phonebpc>0
egen mean2=mean(mobpc) if mobpc>0
egen mean3=mean(pubpc) if pubpc>0
gen test1=phonebpc/mean1
gen test2=mobpc/mean2
gen test3=pubpc/mean3
count if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.) | (test3>=5 & test3!=.))
list hhid urbrur phonebill mobile pubphone phosh test1 test2 test3 if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.) | (test3>=5 & test3!=.))
egen max=rmax(phonebill mobile pubphone) if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.) | (test3>=5 & test3!=.))
* corrections
gen correct=1 if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.) | (test3>=5 & test3!=.))
gen phonebill1=phonebill
replace phonebill1=phonebill/10 if correct==1 & phonebill==max
list hhid if correct==1 & phonebill==max
gen mobile1=mobile
replace mobile1=mobile/10 if correct==1 & mobile==max
list hhid if correct==1 & mobile==max
gen pubphone1=pubphone
replace pubphone1=pubphone/10 if correct==1 & pubphone==max
list hhid if correct==1 & pubphone==max

keep hhid phonebill mobile pubphone phonebill1 mobile1 pubphone1 correct
egen phone=rsum(phonebill1 mobile1 pubphone1)
sort hhid
save util4, replace

use results\utilities, clear
keep hhid waterb
sort hhid
save util5, replace

use util1, clear
sort hhid
merge hhid using util2
tab _merge
drop _merge
sort hhid
merge hhid using util3
tab _merge
drop _merge
sort hhid
merge hhid using util4
tab _merge
drop _merge
sort hhid
merge hhid using util5
tab _merge
drop _merge
sort hhid
save results\utilities1, replace

!del util*.dta

*********************************************************
***                 Total Consumption                 ***
*********************************************************

* We calculate again total consumption using the correct values, and we also add health expenditure

use results\healthexp, clear
sum pambul pdoctor nurse popdoct medic_wp hospital dentist
egen healthexp1=rsum(pambul pdoctor nurse popdoct medic_wp dentist)
collapse (sum) hhsize pambul pdoctor nurse popdoct medic_wp hospital dentist healthexp healthexp1 medicine nlicense, by(hhid)
sort hhid
merge hhid using data\health_b
tab _merge
drop _merge
sort hhid
merge hhid using results\base
tab _merge
drop _merge
count if healthexp==0
gen med_sh=medicine/healthexp
table nlicense, c(m med_sh med med_sh n med_sh) row
sum healthexp, det
gen healexp_pc=healthexp/hhsize
gen healexp_pc1=healthexp1/hhsize
sum healexp_pc healexp_pc1, det

table m5b_q01, c(m healexp_pc med healexp_pc n healexp_pc)
table m5b_q01, c(m healexp_pc1 med healexp_pc1 n healexp_pc1)
drop hh-m5b_q10
keep hhid-nlicense
sort hhid
save results\health, replace

use results\foodexp, clear
sort hhid
merge hhid using results\nfoodexp1
tab _merge
drop _merge
sort hhid
merge hhid using results\edu
tab _merge
drop _merge
sort hhid
merge hhid using results\utilities1
tab _merge
drop _merge
sort hhid
merge hhid using results\durcons1
tab _merge
drop _merge
sort hhid
merge hhid using results\health
tab _merge
drop _merge

* we drop one household that contain some problem as advised by Alberto
drop if hhid==1610
egen totcons=rsum(food sub1-sub10 edu rent1 elect fuel waterb phone durcons healthexp)
for var food sub1-sub10 edu rent1 elect fuel waterb phone durcons healthexp: recode X 0=.

* now we compute shares
gen fodsh=food/totcons
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen rensh=rent1/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen healsh=healthexp/totcons
gen phosh=phone/totcons
* Just to check
egen tot=rsum(fodsh-phosh)
sum tot
drop tot
sort hhid
save temp, replace

* we check outliers in health

egen mhsh=mean(healsh)
egen sdhsh=sd(healsh)
gen test=1 if (healsh>mhsh+2*sdhsh) & healsh!=.
count if test==1
sum healsh if test==1, d
keep if test==1
keep hhid food totcons test healsh hhsize
sort hhid
save temp1, replace
use results\healthexp, clear
rename healthexp ihealth
sort hhid
merge hhid using temp
tab _merge
keep if _merge==3
drop _merge
egen mean=median(ihealth) if ihealth>0
sort hhid
merge hhid using temp1
tab _merge
gen share=ihealth/healthexp
egen max=max(share), by(hhid)
gen test1=ihealth/mean
count if test1>20 & max==share & _merge==3

* there is no much we can do about these values

* we leave it here, also because health probably will not be included


use temp, clear

egen totcons3=rsum(food sub1-sub10 edu elect fuel waterb phone durcons)
egen totcons1=rsum(food sub1-sub10 edu rent1 elect fuel waterb phone durcons)
egen totcons2=rsum(food sub1-sub10 edu rent1 elect fuel waterb phone)
label var totcons "with health"
label var totcons1 "without health"
label var totcons2 "without durables and health"
label var totcons3 "with durables and without rent and health"
egen nfood=rsum(sub1-sub10)
gen pweight=weight*hhsize

sort hhid
merge hhid using results\psupind
tab _merge
drop if _merge==2
drop _merge


* create deciles for the four aggregates

gen pcons=(totcons/hhsize)/psupind
gen pcons1=(totcons1/hhsize)/psupind
gen pcons2=(totcons2/hhsize)/psupind
gen pcons3=(totcons3/hhsize)/psupind

cumul pcons [aw=pweight], gen(cumul1)
cumul pcons1 [aw=pweight], gen(cumul2)
cumul pcons2 [aw=pweight], gen(cumul3)
cumul pcons3 [aw=pweight], gen(cumul4)

local i=1
while `i'<=4 {
gen decile`i'=1
replace decile`i'=2 if cumul`i'>0.1
replace decile`i'=3 if cumul`i'>0.2
replace decile`i'=4 if cumul`i'>0.3
replace decile`i'=5 if cumul`i'>0.4
replace decile`i'=6 if cumul`i'>0.5
replace decile`i'=7 if cumul`i'>0.6
replace decile`i'=8 if cumul`i'>0.7
replace decile`i'=9 if cumul`i'>0.8
replace decile`i'=10 if cumul`i'>0.9
local i=`i'+1
}

label var decile1 "with health"
label var decile2 "without health"
label var decile3 "without durables and health"
label var decile4 "without rent"


* with and without durables
tab decile2 decile3, nof col 

* with and without health
tab decile2 decile1, nof col

* with and without rent
tab decile2 decile4, nof col


log using results\patterns.log, replace
gen foodpc=food/hhsize
table decile4 [pw=pweight], c(m foodpc min foodpc max foodpc)
table area [pw=pweight], c(m foodpc min foodpc max foodpc)
log off

* consumption patterns with health, rent and durables

for var fodsh-phosh: recode X .=0
gen weight1=totcons*weight
save temp, replace

collapse (mean) fodsh-phosh [aw=weight1], by(area)
xpose, clear

log on
* consumption patterns with health, rent and durables
list v1-v3
log off

use temp, clear
collapse (mean) fodsh-phosh [aw=weight1]
xpose, clear
log on
list v1
log off

* consumption patterns without rent and without health

use temp, clear
drop weight1 fodsh-phosh

gen fodsh=food/totcons3
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons3
local i=`i'+1
}
gen edush=edu/totcons3
gen elesh=elect/totcons3
gen fuesh=fuel/totcons3
gen watsh=waterb/totcons3
gen dursh=durcons/totcons3
gen phosh=phone/totcons3

for var fodsh-phosh: recode X .=0
egen tot=rsum(fodsh-phosh)
sum tot
drop tot


gen weight1=totcons3*weight
save temp, replace

collapse (mean) fodsh-phosh [aw=weight1], by(area)
xpose, clear
log on
* consumption patterns without rent and without health
list v1-v3
log off

use temp, clear
collapse (mean) fodsh-phosh [aw=weight1]
xpose, clear
log on
list v1
log off

use temp, clear
collapse (mean) fodsh-phosh [aw=weight1], by(decile4)
xpose, clear
log on
* shares on expenditure without rent and health
list v1-v10
log off

use temp, clear
for var food sub1-sub10 edu elect fuel waterb durcons phone: recode X .=0
drop foodpc
for var food sub1-sub10 edu elect fuel waterb durcons phone: gen Xpc=X/hhsize
collapse (mean) foodpc-phonepc pcons3 [aw=pweight], by(decile4)
xpose, clear
log on
list v1-v10
log off

use temp, clear
for var food sub1-sub10 edu elect fuel waterb durcons phone: recode X .=0
drop foodpc
for var food sub1-sub10 edu elect fuel waterb durcons phone: gen Xpc=X/hhsize
collapse (mean) foodpc-phonepc pcons3 [aw=pweight]
xpose, clear
log on
list v1
log off

use temp, clear
for var food sub1-sub10 edu elect fuel waterb durcons phone: recode X .=0
drop foodpc
for var food sub1-sub10 edu elect fuel waterb durcons phone: gen Xpc=X/hhsize
collapse (mean) foodpc-phonepc pcons3 [aw=pweight], by(area)
xpose, clear
log on
list v1-v3
log off


* now we compute shares, based on expenditure without health

use temp, clear
drop fodsh-phosh
drop weight1
gen fodsh=food/totcons1
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons1
local i=`i'+1
}
gen edush=edu/totcons1
gen rensh=rent1/totcons1
gen elesh=elect/totcons1
gen fuesh=fuel/totcons1
gen watsh=waterb/totcons1
gen dursh=durcons/totcons1
gen phosh=phone/totcons1

for var fodsh-phosh: recode X .=0
egen tot=rsum(fodsh-phosh)
sum tot
drop tot
gen weight1=totcons1*weight
save temp, replace

collapse (mean) fodsh-phosh [aw=weight1], by(decile2)
xpose, clear
log on
* shares on expenditure without health
list v1-v10
log off

use temp, clear
for var food sub1-sub10 edu rent1 elect fuel waterb durcons phone: recode X .=0
drop foodpc
for var food sub1-sub10 edu rent1 elect fuel waterb durcons phone: gen Xpc=X/hhsize
collapse (mean) foodpc-phonepc pcons1 [aw=pweight], by(decile2)
xpose, clear
log on
list v1-v10
log off

use temp, clear
for var food sub1-sub10 edu rent1 elect fuel waterb durcons phone: recode X .=0
drop foodpc
for var food sub1-sub10 edu rent1 elect fuel waterb durcons phone: gen Xpc=X/hhsize
collapse (mean) foodpc-phonepc pcons1 [aw=pweight]
xpose, clear
log on
list v1
log off

use temp, clear
for var food sub1-sub10 edu rent1 elect fuel waterb durcons phone: recode X .=0
drop foodpc
for var food sub1-sub10 edu rent1 elect fuel waterb durcons phone: gen Xpc=X/hhsize
collapse (mean) foodpc-phonepc pcons1 [aw=pweight], by(area)
xpose, clear
log on
list v1-v3
log off


use temp, clear
for var food sub1-sub10 edu rent1 elect fuel waterb durcons healthexp phone: recode X .=0
collapse (mean) fodsh-phosh [aw=weight1], by(area)
xpose, clear
log on
list v1-v3
log off

use temp, clear
collapse (mean) fodsh-phosh [aw=weight1]
xpose, clear
log on
list v1
log close

use temp, clear
drop fodsh-phosh weight1 rent correct mbill estbiladj-cheat phonebill-pubphone1

rename sub1 cleaning
rename sub2 transport
rename sub3 hobby
rename sub4 alcohol
rename sub5 services
rename sub6 clothing
rename sub7 personal
rename sub8 houseart
rename sub9 cerimonies
rename sub10 other

sort hhid
save results\totcons, replace


!del temp*.dta
!del group*.dta
!del util*.dta



