*** This file computes rent (and imputed rent) and utilities (water, electricity, gas, telephone and other)

clear
set mem 10m
set matsize 100

**************************************
*****                            *****
*****           RENT             *****
*****                            *****
**************************************

use results\rentcorr, clear
sort hhid
save, replace

use data\dwelling_cl, clear
* include corrections from Ariana and Elda
sort hhid
merge hhid using results\rentcorr
tab _merge
replace m3a_q15=int(m3a_q15/10) if _merge==3
drop _merge
recode m3a_q15 100002=10000 if psu==394

gen mbashkia=1 if psu==411 | psu==389 | psu==443 | psu==423 | psu==448 | psu==449 | psu==413 | psu==390
replace mbashkia=2 if psu==450 | psu==412 | psu==445 | psu==441 | psu==440 | psu==388 | psu==393 | psu==442
replace mbashkia=3 if psu==444 | psu==416 | psu==422 | psu==421 | psu==447 | psu==414
replace mbashkia=4 if psu==420 | psu==419 | psu==418 | psu==392 | psu==391 | psu==417 | psu==377
replace mbashkia=5 if psu==396 | psu==402 | psu==426 | psu==427 | psu==428 | psu==429 | psu==430 | psu==431 | psu==438 | psu==410 | psu==439
replace mbashkia=6 if psu==378 | psu==395 | psu==382 | psu==383 | psu==384
replace mbashkia=7 if psu==385 | psu==397 | psu==400 | psu==424 | psu==425 | psu==401 | psu==403 | psu==404 | psu==432 | psu==406
replace mbashkia=8 if psu==387 | psu==407 | psu==408 | psu==437 | psu==409 | psu==415 | psu==446
replace mbashkia=9 if psu==433 | psu==434 | psu==435 | psu==436
replace mbashkia=10 if psu==405
replace mbashkia=11 if psu==380 | psu==381 | psu==386 | psu==398 | psu==399 | psu==379

tab m3a_q15
gen rent=m3a_q15
recode rent 0=. 99997=. 99998=. 9999996=. 9999997=. 9999998=.
tab m3a_q16
tab m3a_q16 if rent!=., nol
gen rent1=rent if m3a_q16==1
tab m3a_q17
tab m3a_q13 if m3a_q17!=.
recode m3a_q17 9999997=. 9999998=.
tab m3a_q13 if rent1!=.
replace rent1=m3a_q17 if rent1==.
tab m3a_q13 if rent!=.
replace rent=m3a_q17 if rent==.

tab m3a_q18
tab m3a_q13 if m3a_q18==1
tab m3a_q01 if m3a_q18==1
tab m3a_q01 if m3a_q18==2
count if rent1!=. & m3a_q18==1
tab m3a_q19 if rent1!=. & m3a_q18==1
recode m3a_q19 99997=.
gen mainten=m3a_q19 if rent1!=. & m3a_q18==1
table m3a_q01, c(m mainten med mainten n mainten)
tab mainten if m3a_q01==1
tab rent1 mainten if m3a_q01==1
gen permain=mainten/rent1
tab permain
tab permain mainten if m3a_q01==1
sum permain
egen rent2=rsum(rent1 mainten)
recode rent2 0=.

* rent2 contains all the 'sensible' rent values

count if rent!=. & m3a_q18==1
tab m3a_q19 if rent!=. & m3a_q18==1
recode m3a_q19 99998=.
gen mainten1=m3a_q19 if rent!=. & m3a_q18==1
egen rent3=rsum(rent mainten1)
recode rent3 0=.

* rent3 contains all the rent values

* correct some variables to be used as regressors

egen medqa3=median(m3a_q03), by(psu)
replace m3a_q03=medqa3 if m3a_q03==.

gen year=m3a_q5a
replace year=6 if m3a_q5b>=1995 & m3a_q5b<=1999 & m3a_q5b!=.
replace year=7 if m3a_q5b>=2000 & m3a_q5b!=.

tab m3a_q07
recode m3a_q07 7=.
egen medqa7=median(m3a_q07), by(psu)
replace m3a_q07=medqa7 if m3a_q07==.

gen rooms=m3a_q08-m3a_q09
gen rooms1=m3a_q08
gen lnrooms=ln(rooms1)

gen dista=1 if m3a_q12a<15
replace dista=2 if m3a_q12a>=15 & m3a_q12a<30
replace dista=3 if m3a_q12a>=30 & m3a_q12a<60
replace dista=2 if m3a_q12a>=60

gen distb=1 if m3a_q12b<15
replace distb=2 if m3a_q12b>=15 & m3a_q12b<30
replace distb=3 if m3a_q12b>=30 & m3a_q12b<60
replace distb=2 if m3a_q12b>=60

gen distc=1 if m3a_q12c<15
replace distc=2 if m3a_q12c>=15 & m3a_q12c<30
replace distc=3 if m3a_q12c>=30 & m3a_q12c<60
replace distc=2 if m3a_q12c>=60

rename m3b_q03 water
rename m3b_q12 heat
rename m3b_q39 telep
recode water 2=0 .=0
recode heat 2=0
recode telep 2=0
recode m3b_q22 .=5
recode m3b_q18 .=4

sort hhid
merge hhid using results\base
tab _merge
drop _merge
recode urbrur 2=0

* we check if the values by minibashkia of rent are sensible

gen rentpr=rent2/rooms

table mbashkia, c(m rooms med rooms min rooms max rooms)
table mbashkia, c(m rent2 med rent2 min rent2 max rent2)
table mbashkia, c(m rentpr med rentpr min rentpr max rentpr)

table psu if psu==376 | psu==394, c(m rentpr med rentpr min rentpr max rentpr)
replace mbashkia=3 if psu==376
replace mbashkia=4 if psu==394

table mbashkia, c(m rooms med rooms min rooms max rooms)
table mbashkia, c(m rent2 med rent2 min rent2 max rent2)
table mbashkia, c(m rentpr med rentpr min rentpr max rentpr)

* rent per square meter

gen sm=30 if m3a_q07==1
replace sm=55 if m3a_q07==2
replace sm=85 if m3a_q07==3
replace sm=115 if m3a_q07==4
replace sm=150 if m3a_q07==5

gen rentpsm=rent2/sm
table mbashkia, c(m rentpsm med rentpsm min rentpsm max rentpsm) row

* the state rents for 1 dollar per square meter

list rooms rent2 rentpr if mbashkia==1 & rent2!=.

egen medrentpr=median(rentpr) if mbashkia!=., by(mbashkia)
gen test=rentpr/medrentpr
count if test>5 & test!=.
count if test>4 & test!=.
count if test>3 & test!=.
tab test if test>2 & test!=. 
replace rent2=medrentpr*rooms if test>3 & test!=.

* Now we can use rent2 and rent3 to run a regression and estimate the imputed rent for the missing values

gen lnrent=ln(rent2)
gen lnrent1=ln(rent3)
recode mbashkia .=0

log using results\rent.log, replace

xi: reg lnrent urbrur i.mbashkia i.district i.m3a_q01 i.m3a_q02 i.m3a_q03 i.m3a_q04 year rooms i.m3a_q07 i.m3a_q10 m3a_q11_1-m3a_q11_6 dista distb distc i.m3b_q18 m3b_q22 water heat telep

log close

predict est, xb
sum lnrent est

xi: reg lnrent1 urbrur i.district i.m3a_q01 i.m3a_q02 i.m3a_q03 i.m3a_q04 year rooms i.m3a_q07 i.m3a_q10 m3a_q11_1-m3a_q11_6 dista distb distc i.m3b_q01 i.m3b_q18 m3b_q22 water heat telep
predict est1, xb

table m3a_q16, c(m lnrent1 m est m est1)
table m3a_q16, c(med lnrent1 med est med est1)

tab m3a_q16
* value is too high
count if  m3a_q16==2 & lnrent1>est & lnrent1!=.
count if  m3a_q16==2 & lnrent1>est1 & lnrent1!=.
* value is too low
count if  m3a_q16==3 & lnrent1<est & lnrent1!=.
count if  m3a_q16==3 & lnrent1<est1 & lnrent1!=.

replace lnrent=est if lnrent==.
count if lnrent==.

gen estrent=exp(est)
replace estrent=int(estrent)
tab estrent if rent2!=. & area==1
table area if rent2!=., c(med estrent med rent2)
replace rent2=estrent if rent2==.
table area, c(med rent2 m rent2)
replace rent2=estrent if rent2>estrent & estrent!=.
table area, c(med rent2 m rent2)

keep hhid rent2 estrent
rename rent2 rent
summ rent estrent, d
sort hhid
save temp1, replace


**************************************
*****                            *****
*****           WATER            *****
*****                            *****
**************************************

use results\hhroster, clear
gen hhsize=1
collapse (sum) hhsize, by(hhid)
sort hhid
save temp, replace

use data\dwelling_cl, clear
sort hhid
merge hhid using results\base
tab _merge
drop _merge
sort hhid
merge hhid using temp
tab _merge
drop _merge

tab m3b_q01 m3b_q08
tab m3b_q10
tab m3b_q01 m3b_q08 if m3b_q10==1
* we do not have reference period for arrears

sum m3b_q9a m3b_q9b, d	
recode m3b_q9a 9997=.
recode m3b_q9b 9997=.
sum m3b_q9a m3b_q9b, d	

count if m3b_q9a==m3b_q9b
count if m3b_q9a!=. & m3b_q9b==.
replace m3b_q9b=m3b_q9a if m3b_q9a!=. & m3b_q9b==.
count if m3b_q9a==. & m3b_q9b!=.
egen waterb=rmean(m3b_q9a m3b_q9b)
tab m3b_q01 if waterb!=.

log using "results\water.log", replace
tab m3b_q01 urbrur
tab m3b_q01 urbrur if waterb!=.

log off

gen pcwater=waterb/hhsize

* When the household receives running water theoretically this should be paid monthly and with a fixed amount per capita, this amount varies in each city

* verify the relationship between household size and water bill 
xi: reg waterb hhsize i.district*i.urbrur if m3b_q01==1
xi: reg waterb hhsize i.district*i.urbrur if m3b_q01==2

* there is a strong and clear relationship between water bill and household size in the case of water inside, less if water outside

* we check whether there are differences between households receiving piped water inside or outside
table district urbrur if m3b_q01==1, c(m pcwater)
table district urbrur if m3b_q01==2, c(m pcwater)

* ask Ariana: both households receiving water outside and inside should pay the same

log on

* running water inside
table district if urbrur==1 & m3b_q01==1, c(median pcwater sd pcwater n pcwater) row
table district if urbrur==2 & m3b_q01==1, c(median pcwater sd pcwater n pcwater) row

log close

* running water outside
table district if m3b_q01==2, c(median pcwater sd pcwater n pcwater)

* we can use the median values to impute water costs for households who receive running water, but don't pay

egen medpcwat=median(pcwater) if m3b_q01==1 | m3b_q01==2, by(district urbrur)

replace waterb=hhsize*medpcwat if m3b_q01==1 | m3b_q01==2

tab waterb urbrur if m3b_q01>2

keep hhid waterb
sort hhid
save temp11, replace


**************************************
*****                            *****
*****         Electricity        *****
*****                            *****
**************************************

use results\hhroster, clear
gen hhsize=1
collapse (sum) hhsize, by(hhid)
sort hhid
save temp, replace

use data\dwelling_cl, clear
sort hhid
merge hhid using temp
tab _merge
drop _merge
sort hhid
merge hhid using results\base
tab _merge
drop _merge

*** we can run a regression

* quantity, type of use, household size

gen kwh=m3b_q24
recode kwh 7=. 8=.
gen mbill=m3b_q27a
recode mbill 9999997=.
replace mbill=mbill/m3b_q27b

table kwh, c(m mbill med mbill n mbill)
* average values seem to be correct

* kwh<=100, it should be no more than 500
tab mbill if kwh==1
* 100<kwh<=200, it should be between 500 and 1000
tab mbill if kwh==2 
* 200<kwh<=300, it should be between 1000 and 1500
tab mbill if kwh==3
* 300<kwh<=400, it should be between 1500 and 2460
tab mbill if kwh==4
* 400<kwh<=500, it should be between 2460 and 3420
tab mbill if kwh==5
* kwh>500, it should be more than 3420
tab mbill if kwh==6

* we are in a difficult situation if we want to make changes, should we believe in values or in quantities (we leave them as they are for now)

* we correct these values giving the same price to each kwh

gen mbilladj=((mbill-1500)/9.6)*5+1500 if mbill>1500 & mbill!=.
replace mbilladj=mbill if mbill<=1500 & mbill!=.

gen arrear=m3b_q28
recode arrear 2=0
gen arvalue=m3b_q29
recode arvalue 9997=. 9998=. 9999997=. 9999998=.
count if m3b_q30==. & arvalue!=.
table m3b_q30, c(m arvalue n arvalue)
gen areasq=m3a_q07
recode areasq 7=.

gen elect=0 if m3b_q17_6==1
recode urbrur 2=0

sum kwh mbilladj arrear arvalue m3b_q30 m3b_q17_1-m3b_q17_5 areasq hhsize if elect==.

* if we assume that the expenditure for electricity is more or less stable each month than the last bill reported is a good estimate
* and some missing values can be inputed considering use of electricity, quantity range consumed, house size

xi: reg mbilladj kwh m3b_q17_1-m3b_q17_5 areasq hhsize urbrur i.district if elect==.
predict est, xb
sum mbilladj est

tab est if mbilladj==.

xi: reg mbilladj m3b_q17_1-m3b_q17_5 areasq hhsize urbrur i.district if elect==.
predict est1, xb
sum mbilladj est1

tab est1 if mbilladj==. & est==.

xi: reg mbilladj m3b_q17_1-m3b_q17_5 hhsize urbrur i.district if elect==.
predict est2, xb
sum mbilladj est2

tab est2 if mbilladj==. & est==. & est1==.

gen estbiladj=est
replace estbiladj=est1 if estbiladj==.
replace estbiladj=est2 if estbiladj==.

gen mbilla1=arvalue/3 if m3b_q30==1
gen mbilla2=arvalue/5 if m3b_q30==2
gen mbilla3=arvalue/9 if m3b_q30==3
gen mbilla4=arvalue/18 if m3b_q30==4

local i=1
while `i'<=4 {
replace mbilla`i'=((mbilla`i'-1500)/9.6)*5+1500 if mbilla`i'>1500 & mbilla`i'!=.
local i=`i'+1
}

list mbilladj est mbilla1 est1 if mbilladj==. & mbilla1!=.
list mbilladj est mbilla2 est1 if mbilladj==. & mbilla2!=.
list mbilladj est mbilla3 est1 if mbilladj==. & mbilla3!=.
list mbilladj est mbilla4 est1 if mbilladj==. & mbilla4!=.

replace elect=mbilladj if elect==.
replace elect=est if elect==.
replace elect=mbilla1 if elect==.
replace elect=est1 if elect==.
replace elect=est2 if elect==.

count if elect==.

table area [pw=weight], c(m elect)  

keep hhid elect estbiladj mbill
sort hhid
save temp2, replace


**************************************
*****                            *****
*****           GAS              *****
*****                            *****
**************************************

* cylinder where the capacity of the cylinder was reported only in the questionnaire were checked and include in a separate file that is merged with the original one 
use results\hhidofother, clear
sort hhid
save, replace

use data\dwelling_cl, clear
sort hhid
merge hhid using results\hhidofother
tab _merge
drop _merge

gen gas=1 if m3b_q33==1
recode gas .=0

* we have type of cilinder (quantity) 

tab m3b_q35
tab m3b_q35, nol
table m3b_q35, c(m m3b_q36 med m3b_q36)
tab m3b_q36 if m3b_q35==4
tab m3b_q36 if m3b_q35==3
tab m3b_q36 if m3b_q35==2
tab m3b_q36 if m3b_q35==1

recode m3b_q36 99997=.
gen value=m3b_q36
gen quant=10 if m3b_q35==1
replace quant=15 if m3b_q35==2
replace quant=20 if m3b_q35==3
replace quant=quantity if m3b_q35==4
gen gelect=m3b_q34_1
gen gheat=m3b_q34_2
gen gcook=m3b_q34_3
gen gother=m3b_q34_4

gen perioda=m3b_q37a
gen periodb=m3b_q37b

* the approach should be to fix price according to quantity and then divide by period of use, distinguishing by summer and winter

table quant, c(m value med value n value)

gen value1=quant*100
* now we consider what is the period of consumption, we make the following adjustment
recode perioda 1=0.5 2=1.5 3=2.5 4=4
recode periodb 1=0.5 2=1.5 3=2.5 4=4 5=0
gen wmonths=6/12
gen smonths=6/12
gen winter=wmonths*(value1/perioda)
gen summer=smonths*(value1/periodb)

egen gascons=rsum(winter summer)
replace gascons=0 if gas==0

keep hhid gascons
sort hhid
save temp3, replace


**************************************
*****                            *****
*****           OTHER            *****
*****                            *****
**************************************


use data\dwelling_cl, clear

* we correct two cases as suggested by Ariana and Elda
recode m3b_q38a_1 80000=8000 if hhid==4007
recode m3b_q38a_2 5000=500 if hhid==9004

sort hhid
merge hhid using results\base
tab _merge
drop _merge

* we want to have an idea of what are the sources used by household for 1) lighting, 2) heating 3) cooking
gen heat_s=m3b_q16
label val heat_s M3B_Q16
tab heat_s

gen heatsource=1 if m3b_q17_2==1 & m3b_q34_2!=1
replace heatsource=2 if m3b_q34_2==1 & m3b_q17_2!=1
replace heatsource=3 if m3b_q34_2==1 & m3b_q17_2==1
replace heatsource=0 if m3b_q34_2!=1 & m3b_q17_2!=1
lab def use 0 "no gas no elect"
lab def use 1 "only elect", add
lab def use 2 "only gas", add
lab def use 3 "both gas and elect", add
lab val heatsource use
tab heatsource m3b_q12
replace heatsource=4 if heatsource==1 & m3b_q12==1
replace heatsource=5 if heatsource==3 & m3b_q12==1
lab def use 4 "both elect and central", add
lab def use 5 "both gas, elect and central", add
lab val heatsource use

tab heatsource heat_s

gen light_s=m3b_q32
label val light_s M3B_Q32
gen lightsource=1 if m3b_q17_1==1 & m3b_q34_1!=1 
replace lightsource=2 if m3b_q34_1==1 & m3b_q17_1!=1
replace lightsource=3 if m3b_q34_1==1 & m3b_q17_1==1
replace lightsource=0 if m3b_q34_1!=1 & m3b_q17_1!=1
lab val lightsource use

tab lightsource light_s

gen cooksource=1 if m3b_q17_3==1 & m3b_q34_3!=1 
replace cooksource=2 if m3b_q34_3==1 & m3b_q17_3!=1
replace cooksource=3 if m3b_q34_3==1 & m3b_q17_3==1
replace cooksource=0 if m3b_q34_3!=1 & m3b_q17_3!=1
lab val cooksource use

gen f_heat=1 if heat_s==2
gen c_heat=1 if heat_s==5
gen k_heat=1 if heat_s==4
gen o_heat=1 if heat_s==7
gen k_light=1 if light_s==2 | light_s==1
gen o_light=1 if light_s==4
for var f_heat-o_light: recode X .=0

* Other products used for heating and lighting (firewood, coal, oil, diesel, other)

gen firew_w=1 if m3b_q38a_1>0 & m3b_q38a_1!=.
gen firew_s=1 if m3b_q38a_2>0 & m3b_q38a_2!=.
gen coal_w=1 if m3b_q38b_1>0 & m3b_q38b_1!=.
gen coal_s=1 if m3b_q38b_2>0 & m3b_q38b_2!=.
gen oil_w=1 if m3b_q38c_1>0 & m3b_q38c_1!=.
gen oil_s=1 if m3b_q38c_2>0 & m3b_q38c_2!=.
gen dies_w=1 if m3b_q38d_1>0 & m3b_q38d_1!=.
gen dies_s=1 if m3b_q38d_2>0 & m3b_q38d_2!=.
gen other_w=1 if m3b_q38e_1>0 & m3b_q38e_1!=.
gen other_s=1 if m3b_q38e_2>0 & m3b_q38e_2!=.
for var m3b_q38a_1-m3b_q38e_2: recode X 99997=.
gen vfirew_w=m3b_q38a_1
gen vfirew_s=m3b_q38a_2
gen vcoal_w=m3b_q38b_1
gen vcoal_s=m3b_q38b_2
gen voil_w=m3b_q38c_1
gen voil_s=m3b_q38c_2
gen vdies_w=m3b_q38d_1
gen vdies_s=m3b_q38d_2
gen vother_w=m3b_q38e_1
gen vother_s=m3b_q38e_2

* we expect that winter months are 6 and summer months 6
gen wmonths=6/12
gen smonths=6/12

*** firewood

*** we substitiute missing with values in the same psu where household use the source in the same way.
* winter
tab heatsource firew_w
tab heat_s firew_w
count if firew_w==1 & vfirew_w==.
tab f_heat if firew_w==1 & vfirew_w==.
tab heatsource if firew_w==1 & vfirew_w==.
gen tobeused=vfirew_w if f_heat==1 & heatsource==0
egen medfire1=median(tobeused), by(psu)
tab medfire1 if firew_w==1 & vfirew_w==. & heatsource==0
replace vfirew_w=medfire1 if firew_w==1 & vfirew_w==. & heatsource==0
egen medfire2=median(tobeused), by(district)
tab medfire2 if firew_w==1 & vfirew_w==. & heatsource==0
replace vfirew_w=medfire2 if firew_w==1 & vfirew_w==. & heatsource==0
drop tobeused medfire1 medfire2
gen tobeused=vfirew_w if f_heat==1 & heatsource==1
egen medfire1=median(tobeused), by(psu)
replace vfirew_w=medfire1 if firew_w==1 & vfirew_w==. & heatsource==1
egen medfire2=median(tobeused), by(district)
replace vfirew_w=medfire2 if firew_w==1 & vfirew_w==. & heatsource==1
egen medfire3=median(tobeused)
replace vfirew_w=medfire3 if firew_w==1 & vfirew_w==. & heatsource==1
drop tobeused medfire1 medfire2 medfire3
count if firew_w==1 & vfirew_w==.

* summer
tab heatsource firew_s
tab heat_s firew_s
count if firew_s==1 & vfirew_s==.
tab f_heat if firew_s==1 & vfirew_s==.
tab heatsource if firew_s==1 & vfirew_s==.
gen tobeused=vfirew_s if f_heat==1 & heatsource==0
egen medfire1=median(tobeused), by(psu)
replace vfirew_s=medfire1 if firew_s==1 & vfirew_s==. & heatsource==0
egen medfire2=median(tobeused), by(district)
replace vfirew_s=medfire2 if firew_s==1 & vfirew_s==. & heatsource==0
drop tobeused medfire1 medfire2
gen tobeused=vfirew_s if f_heat==1 & heatsource==1
egen medfire1=median(tobeused), by(psu)
replace vfirew_s=medfire1 if firew_s==1 & vfirew_s==. & heatsource==1
egen medfire2=median(tobeused), by(district)
replace vfirew_s=medfire2 if firew_s==1 & vfirew_s==. & heatsource==1
egen medfire3=median(tobeused)
replace vfirew_s=medfire3 if firew_s==1 & vfirew_s==. & heatsource==1
drop tobeused medfire1 medfire2 medfire3
count if firew_s==1 & vfirew_s==.

gen firewoodw=wmonths*vfirew_w
gen firewoods=smonths*vfirew_s
egen firewood=rsum(firewoodw firewoods)
drop firewoodw firewoods

egen totfire=rsum(vfirew_w vfirew_s)

* it seems that there are some problems with firewood, some household reported the season expenditure instead of the monthly one
* we correct assuming that whenever households report an expenditure above 4000 they refer to annual expenditure
drop firewood
gen firewood=totfire/2 if totfire<=4000
replace firewood=totfire/12 if totfire>4000


*** coal

* winter and summer
tab heatsource coal_w
tab heat_s coal_w
count if coal_w==1 & vcoal_w==.
tab heatsource coal_s
tab heat_s coal_s
count if coal_s==1 & vcoal_s==.
gen coalw=wmonths*vcoal_w
gen coals=smonths*vcoal_s
egen coal=rsum(coalw coals)
drop coalw coals


*** oil, kerosene

tab heatsource oil_w
tab heat_s oil_w
count if oil_w==1 & voil_w==.
tab heatsource if oil_w==1 & voil_w==.
tab k_heat if oil_w==1 & voil_w==.
gen tobeused=voil_w if k_heat==1 & heatsource==1
tab tobeused
egen medoil=median(tobeused)
replace voil_w=medoil if oil_w==1 & voil_w==.
drop tobeused medoil

tab heatsource oil_s
tab heat_s oil_s
count if oil_s==1 & voil_s==.
tab heatsource if oil_s==1 & voil_s==.
tab k_heat if oil_s==1 & voil_s==.
gen tobeused=voil_s if k_heat==1 & heatsource==1
tab tobeused
egen medoil=median(tobeused)
replace voil_s=medoil if oil_s==1 & voil_s==.
drop tobeused medoil

gen oilw=wmonths*voil_w
gen oils=smonths*voil_s
egen oilker=rsum(oilw oils)
drop oilw oils

* we correct some problems with old and new leks
replace oilker=oilker/10 if oilker>4000


*** diesel

tab heatsource dies_w
tab heat_s dies_w
count if dies_w==1 & vdies_w==.
tab heatsource dies_s
tab heat_s dies_s
count if dies_s==1 & vdies_s==.
gen diesw=wmonths*vdies_w
gen diess=smonths*vdies_s
egen diesel=rsum(diesw diess)
drop diesw diess
* we correct some problems with old and new leks
replace diesel=diesel/10 if diesel>40000

*** other

tab heatsource other_w
tab heat_s other_w
tab lightsource other_w
tab light_s other_w
count if other_w==1 & vother_w==.
tab heatsource if other_w==1 & vother_w==.
tab heat_s if other_w==1 & vother_w==.
tab lightsource if other_w==1 & vother_w==.
tab light_s if other_w==1 & vother_w==.
replace vother_w=0 if other_w==1 & vother_w==.
tab heatsource other_s
tab heat_s other_s
count if other_s==1 & vother_s==.

gen otherw=wmonths*vother_w
gen others=smonths*vother_s
egen other=rsum(otherw others)
drop otherw others


*** central heating

gen cheat=(m3b_q15*m3b_q13)/12
recode cheat .=0


*** telephone

tab m3b_q39
gen telephone=1 if m3b_q40==1
gen phonebill=m3b_q41a
recode phonebill 999997=. 999998=.
replace phonebill=phonebill/m3b_q41b
gen mobile=m3b_q44
gen missmob=1 if mobile==999997
recode mobile 999997=.
tab m3b_q43 if mobile==.
gen pubphone=m3b_q46

* replace missing mobile
tab telephone if missmob==1
tab pubphone if missmob==1
tab district if missmob==1
* use cases where only mobile phone is used
gen tobeused=mobile if mobile>0 & mobile!=. & telephone==. & pubphone==.
egen medmob=median(tobeused), by(psu)
tab medmob if missmob==1
replace mobile=medmob if missmob==1
egen medmob1=median(tobeused), by(district)
replace mobile=medmob1 if missmob==1 & mobile==.
drop tobeused medmob medmob1

* replace missing phonebill
count if telephone==1 & phonebill==.
tab pubphone if telephone==1 & phonebill==.
tab mobile if telephone==1 & phonebill==.
* use cases where only telephone is used
gen tobeused=phonebill if mobile==. & pubphone==.
egen medtel=median(tobeused), by(psu)
tab medtel if telephone==1 & phonebill==. & mobile==.
replace phonebill=medtel if telephone==1 & phonebill==. & mobile==.
egen medtel1=median(tobeused), by(district)
tab medtel1 if telephone==1 & phonebill==. & mobile==.
replace phonebill=medtel1 if telephone==1 & phonebill==. & mobile==.
drop tobeused medtel medtel1
* use cases where both telphone and mobile are used
gen tobeused=phonebill if mobile>0 & mobile!=. & pubphone==.
egen medtel=median(tobeused), by(psu)
tab medtel if telephone==1 & phonebill==. & mobile!=.
replace phonebill=medtel if telephone==1 & phonebill==. & mobile!=.
drop tobeused medtel

for var firewood coal oilker diesel other cheat mobile phonebill pubphone: recode X .=0
sum firewood coal oilker diesel other cheat mobile phonebill pubphone
keep hhid firewood coal oilker diesel other cheat mobile phonebill pubphone
sort hhid
save temp4, replace



**************************************
*****                            *****
*****        ALL TOGETHER        *****
*****                            *****
**************************************

use temp1, clear
sort hhid
merge hhid using temp11
tab _merge
drop _merge
sort hhid
merge hhid using temp2
tab _merge
drop _merge
sort hhid
merge hhid using temp3
tab _merge
drop _merge
sort hhid
merge hhid using temp4
tab _merge
drop _merge
sort hhid
save results\utilities, replace


!del temp*.dta

